;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File Name    : mwa100m.asm
; Purpose      : MyWatch Application 100th minute State Manager
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;DO NOT MODIFY THE FOLLOWING SUBROUTINE DEFINITION;;;;;;;;;;;;;;;;;

                IF @DEF('SUBROUTINE')
                    UNDEF SUBROUTINE
                ENDIF
                DEFINE  SUBROUTINE      "'mwa100m'"
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Module Name : mwa100mStateManager
; Description : MyWatch Application 100th minute State Manager.
; Assumptions : Display is cleared on first time entry into the state.
; Input(s)    : CORECurrentEvent  - system event to be processed
;               COREEventArgument - event extra information
; Output(s)   : None
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

                GLOBAL  mwa100mStateManager

mwa100mStateManager:

                ; Set IYReg the address of the MyWatch ASD.
                ld      IY, [CORECurrentASDAddress]

                ld      A, [CORECurrentEvent]

                ; Check if state entry event.
                cp      A, #MWA_STATEENTRY
                jr      Z, mwaStateEntryEvent

                ; Check if mode depress event.
                cp      A, #MWA_MODEDEPRESS
                jr      Z, mwaModeDepressEvent

                ; Check if start/split depress event.
                cp      A, #MWA_STARTDEPRESS
                jr      Z, mwaStartDepressEvent

                ; Check if stop/reset depress event.
                cp      A, #MWA_STOPDEPRESS
                jr      Z, mwaStopDepressEvent
                
                ; Check if crown set event.
                cp      A, #MWA_CROWNSET
                jr      Z, mwaPulledCrownEvent

                ; Check if TOD display update event
                cp      A,#MWA_UPDATE_TODRES
                jr      Z,mwaUpdateTODResEvent
                
                ; Check if crown CW event.
                cp      A,#MWA_CWPULSES
                jr      Z,mwaCWEvent
                
                ; Check if crown CCW event.
                cp      A,#MWA_CCWPULSES
                jr      Z,mwaCCWEvent
                
                ret
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;; EVENT HANDLERS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


mwaModeDepressEvent:
                ;**************************************************************
                ;
                ;                       MODE DEPRESS
                ;
                ;**************************************************************

                ;This is default to go to the next mode

                CORE_REQ_MODE_CHANGE_NEXT

                ret


mwaStartDepressEvent:
                ;**************************************************************
                ;
                ;                       START DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTARTSTATE
                CORE_REQ_STATE_CHANGE
                ret


mwaStopDepressEvent:
                ;**************************************************************
                ;
                ;                       STOP DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTOPSTATE
                CORE_REQ_STATE_CHANGE
                ret
                

mwaPulledCrownEvent:
                ;**************************************************************
                ;
                ;                       CROWN SET
                ;
                ;**************************************************************

                ld      B, #CORESTATE2
                CORE_REQ_STATE_CHANGE

                ret

mwaCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CW
                ;
                ;**************************************************************

                ld      A, #CMD_NEXT
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE

                ret

mwaCCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CCW
                ;
                ;**************************************************************

                ld      A, #CMD_PREV
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE

                ret


mwaStateEntryEvent:
                ;**************************************************************
                ;
                ;                       STATE ENTRY
                ;
                ;**************************************************************

                car     DisplayLockFlag

                ; Enable pulse mode
                CORE_ENABLE_PULSE_MODE

                car     ReadLocalTime
                car     Redraw_Full

                ;-- Enable seconds updates from the primary time zone resource
                ld      A, [COREPTZIndex]
                KTOD_ENABLE_DISP_UPD_SEC_EVENT
                
                ret


mwaUpdateTODResEvent:
                ;**************************************************************
                ;
                ;                       UPDATE TOD RESSOURCE (1s)
                ;
                ;**************************************************************

                ;Get the current update status flag of the primary time zone resource
                car     ReadLocalTime

                ld      A, [COREPTZIndex]
                KTOD_GET_UPDATE_FLAGS
                bit     A,#bKTODMinuteUpd
                jr      Z,lbUpdate1
                  car     Redraw_Full
                  car     TestRandomMode
                  ret
lbUpdate1:                
                car     Display60Time
                car     Display100Time
                
                Ret

 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; FUNCTIONS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


Redraw_Full:
                car     DisplayIcons
                car     DisplayDateInSegment
                car     Display60Time
                car     Display100Time
                car     DisplayCustomDOW
                ret
                
;-- Display Icons
DisplayIcons:

                ;-- Display First line icon
                ld      B, #5
                ld      IY,#Time60
                ld      IX, #0F905H
                UTL_COPY_IYREG_TO_IXREG

                ;-- Display Second line icon
                ld      B, #8
                ld      IY,#Time100
                ld      IX, #0FA02H
                UTL_COPY_IYREG_TO_IXREG

                RET

                
;-- Display the home time    
Display60Time:
                ;-- Display hour                
                ld  A, [dTODHour]
                ld  IX, #LCDMAINDMLINE1COL10
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_SUP_ZERO_MSD
                
                ;-- Display Colon
                ld  L, #DM5_COLON
                ld  IX, #LCDMAINDMLINE1COL20
                LCD_DISP_SMALL_PROP_WIDTH_DM_CHAR
                
                ;-- Display minute
                ld  A, [dTODMin]
                ld  IX, #LCDMAINDMLINE1COL22
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP

                ;-- Display Period
                ld L, #DM5_PERIOD
                ld IX, #LCDMAINDMLINE1COL32
                LCD_DISP_SMALL_PROP_WIDTH_DM_CHAR
                
                ;-- Display second
                ld  A, [dTODSec]
                ld  IX, #LCDMAINDMLINE1COL34
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP
                
                Ret
                
;-- Display the 2nd time    
Display100Time:
                ;-- Display hour                
                ld  A, [dTODHour]
                ld  IX, #LCDMAINDMLINE2COL10
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_SUP_ZERO_MSD
                
                ;-- Display Colon
                ld  L, #DM5_COLON
                ld  IX, #LCDMAINDMLINE2COL20
                LCD_DISP_SMALL_PROP_WIDTH_DM_CHAR

                ;-- Calc the 100th minute
                ld    A, [dTODMin]
                UTL_CONVERT_1BYTE_BCD_TO_1BYTE_HEX   ;A=>CONV=>A
                ld    L,#60
                mlt   ;HL=A*L
                push HL
                
                ld    A, [dTODSec]
                UTL_CONVERT_1BYTE_BCD_TO_1BYTE_HEX   ;A=>CONV=>A
                pop   HL
                ld    B,#0
                add   HL,BA
                ld    A,#36
                div   ;L=HL/A H=Remainder
                
                UTL_CONVERT_HEX_TO_2DIGIT_BCD   ;L=>CONV=>A
                
                ;-- Display minute
                ld  IX, #LCDMAINDMLINE2COL22
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP

                Ret
                

              
                
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; DATAS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;Home:           db 04H,1EH,15H,15H,15H,1EH,04H
Time60:         db 0EH,11H,17H,15H,0EH
Time100:       db 08H,3CH,18H,24H,18H,18H,24H,18H

dDualTimeBuffer:
dDualSec:    db 00 ;second
dDualMin:    db 00 ;minute
dDualHour:   db 00 ;hour
dDualDate:   db 00 ;date
dDualMonth:  db 00 ;month
dDualYearLo: db 00 ;year lo
dDualYearHi: db 00 ;year hi
dDualDow:    db 00 ;dow
dDualWeek:   db 00 ;week number










                
