;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File Name    : mwaAnalog.asm
; Purpose      : MyWatch Application analog/digital State Manager
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;DO NOT MODIFY THE FOLLOWING SUBROUTINE DEFINITION;;;;;;;;;;;;;;;;;

                IF @DEF('SUBROUTINE')
                    UNDEF SUBROUTINE
                ENDIF
                DEFINE  SUBROUTINE      "'mwaAnalog'"
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Module Name : mwaAnalogStateManager
; Description : MyWatch Application Analog/Digital State Manager.
; Assumptions : Display is cleared on first time entry into the state.
; Input(s)    : CORECurrentEvent  - system event to be processed
;               COREEventArgument - event extra information
; Output(s)   : None
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

                GLOBAL  mwaAnalogStateManager

mwaAnalogStateManager:

                ; Set IYReg the address of the MyWatch ASD.
                ld      IY, [CORECurrentASDAddress]

                ld      A, [CORECurrentEvent]

                ; Check if state entry event.
                cp      A, #MWA_STATEENTRY
                jr      Z, mwaStateEntryEvent

                ; Check if mode depress event.
                cp      A, #MWA_MODEDEPRESS
                jr      Z, mwaModeDepressEvent

                ; Check if start/split depress event.
                cp      A, #MWA_STARTDEPRESS
                jr      Z, mwaStartDepressEvent

                ; Check if stop/reset depress event.
                cp      A, #MWA_STOPDEPRESS
                jr      Z, mwaStopDepressEvent
                
                ; Check if crown set event.
                cp      A, #MWA_CROWNSET
                jr      Z, mwaPulledCrownEvent

                ; Check if TOD display update event
                cp      A,#MWA_UPDATE_TODRES
                jr      Z,mwaUpdateTODResEvent
                
                ; Check if crown CW event.
                cp      A,#MWA_CWPULSES
                jr      Z,mwaCWEvent
                
                ; Check if crown CCW event.
                cp      A,#MWA_CCWPULSES
                jr      Z,mwaCCWEvent
                
                ret
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;; EVENT HANDLERS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


mwaModeDepressEvent:
                ;**************************************************************
                ;
                ;                       MODE DEPRESS
                ;
                ;**************************************************************

                ;This is default to go to the next mode

                CORE_REQ_MODE_CHANGE_NEXT

                ret


mwaStartDepressEvent:
                ;**************************************************************
                ;
                ;                       START DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTARTSTATE
                CORE_REQ_STATE_CHANGE
                ret


mwaStopDepressEvent:
                ;**************************************************************
                ;
                ;                       STOP DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTOPSTATE
                CORE_REQ_STATE_CHANGE
                ret
                

mwaPulledCrownEvent:
                ;**************************************************************
                ;
                ;                       CROWN SET
                ;
                ;**************************************************************

                ld      B, #CORESTATE2
                CORE_REQ_STATE_CHANGE

                ret

mwaCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CW
                ;
                ;**************************************************************

                ld      A, #CMD_NEXT
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE

                ret

mwaCCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CCW
                ;
                ;**************************************************************

                ld      A, #CMD_PREV
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE

                ret


mwaStateEntryEvent:
                ;**************************************************************
                ;
                ;                       STATE ENTRY
                ;
                ;**************************************************************

                car     DisplayLockFlag
                
                ; Enable pulse mode
                CORE_ENABLE_PULSE_MODE

                car     ReadLocalTime
                car     Redraw_Full
                ;car     DisplayEmptyWatch
                ;car     DisplayDateInSegment
                ;car     DisplayTime
                ;car     DisplayAnalogTime
                ;car     DisplayCustomDOW

                ;-- Enable seconds updates from the primary time zone resource
                ld      A, [COREPTZIndex]
                KTOD_ENABLE_DISP_UPD_SEC_EVENT
                
                ret


mwaUpdateTODResEvent:
                ;**************************************************************
                ;
                ;                       UPDATE TOD RESSOURCE (1s)
                ;
                ;**************************************************************

                ;Get the current update status flag of the primary time zone resource
                car     ReadLocalTime

                ld      A, [COREPTZIndex]
                KTOD_GET_UPDATE_FLAGS
                bit     A,#bKTODMinuteUpd
                jr      Z,lbUpdate1
                  ;LCD_CLR_DISPLAY
                  car     Redraw_Full
                  ;car     DisplayEmptyWatch
                  ;car     DisplayDateInSegment
                  ;car     DisplayAnalogTime
                  ;car     DisplayCustomDOW
                  car     TestRandomMode
                  ret
lbUpdate1:                
                car     DisplayTime
                
                Ret

 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; FUNCTIONS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

Redraw_Full:
                car     DisplayEmptyWatch
                car     DisplayDateInSegment
                car     DisplayAnalogTime
                car     DisplayCustomDOW
                car     DisplayTime
                ret


;-- Display empty Watch
DisplayEmptyWatch:
                ld  B, #15
                ld  IY,#WatchLine1
                ld  IX, #0F903H   ;0F902H
                UTL_COPY_IYREG_TO_IXREG    
                
                ld  B, #17
                ld  IY,#WatchLine2
                ld  IX, #0FA02H
                UTL_COPY_IYREG_TO_IXREG                
                Ret          

;-- Display the digital time    
DisplayTime:
                ;-- Display hour                
                ld  A, [dTODHour]
                ld  IX, #LCDMAINDMLINE1COL22
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_SUP_ZERO_MSD

                ;-- Display Colon
                ld  L, #DM5_COLON
                ld  IX, #LCDMAINDMLINE1COL32
                LCD_DISP_SMALL_PROP_WIDTH_DM_CHAR
                
                ;-- Display minute
                ld  A, [dTODMin]
                ld  IX, #LCDMAINDMLINE1COL34
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP
                
                ;-- Display second
                ld  A, [dTODSec]
                ld  IX, #LCDMAINDMLINE2COL34
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP
                
                Ret

;-- Display the analog time    
DisplayAnalogTime:
                ;-- Minute display
                ld    A,[dTODMin]
                UTL_CONVERT_1BYTE_BCD_TO_1BYTE_HEX
                ld    H,#0
                sll   A ;add
                ld    L,A
                ld    A,#5
                div         ;L=HL/A
                push  L

;                ld    A,#8  ;15
;                mlt         ;HL=L*A
;                
;                ld    IX,#Pix00
;                add   IX,HL
;                
;                ld    B,[IX]
;                inc   IX
;                car   DispAnalog
                
                Ld    B,#0
                Car   Display
                
                ;-- Hour display
                ld    A,[dTODHour]
                UTL_CONVERT_1BYTE_BCD_TO_1BYTE_HEX
                ld    H,#0
                ld    L,A
                ld    A,#12
                div         ;L=HL/A H=remainder
                ld    L,H
                ld    A,#2
                mlt
                
                pop   A
                cp    A,#12  ;6
                jrs   LE,DispAnalogL1
                  inc L
                  cp  L,#24  ;12
                  jr  NZ,DispAnalogL1
                    ld  L,#0 
DispAnalogL1:
;                ld    A,#15
;                mlt         ;HL=L*A
;                
;                ld    IX,#Pix00
;                add   IX,HL
;                
;                ld    B,[IX]
;                dec   B
;                inc   IX
;                car   DispAnalog
                ld    B,#1
                car   Display
                
                ret                

;--
; L: Offset
; B: 0=minute display 1=hour display
Display:
                ld    A,#8
                mlt         ;HL=L*A
                
                ld    IX,#Pix00
                add   IX,HL
                
                ld    A,[IX]
                sub   A,B
                ex    A,B
                inc   IX
                car   DispAnalog
                
                ret




                
DispAnalog:                
                ;-- B  : Number of data to read
                ;-- IX : Address of the first data
lbLoopDispAnalog:
                push  B

                ld    A,[IX]
                ;add   A,#22H
                upck  ;A=> h>B l>A  (=> X>B Y>A)
                ex    A,B
                ;inc   IX
                ;ld    B,[IX]
                inc a
                inc a
                inc b
                inc b
                
                ; Turn on Pixel (x = A, y = B)
                LCD_DISPLAY_MAIN_DM_PIXEL
                inc   IX
                
                pop   B
                DJR   NZ,lbLoopDispAnalog
                      
                Ret
                
                
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; DATAS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;-- Watch First line -- 
;WatchLine1: db 00H,08H,00H,00H,02H,00H,00H,01H,00H,00H,02H,00H,00H,08H,00H
;WatchLine1: db 00H,04H,00H,00H,01H,00H,00H,00H, 01H, 00H,00H,00H,01H,00H,00H,04H ;,00H
WatchLine1: db 04H,00H,00H,01H,00H,00H,00H, 01H, 00H,00H,00H,01H,00H,00H,04H ;,00H
;WatchLine2: db 01H,04H,00H,00H,10H,00H,00H,21H,00H,00H,10H,00H,00H,04H,01H
WatchLine2: db 01H,08H,00H,00H,20H,00H,00H,00H, 21H, 00H,00H,00H,20H,00H,00H,08H,01H



;-- Analog display (pixel datas)
;Pix00:       db  04,  09, 05,  09, 04,  09, 03,  09, 02,  00, 00,  00, 00,  00, 00
;Pix00_01:    db  04,  09, 05,  10, 04,  10, 03,  11, 02,  00, 00,  00, 00,  00, 00
;Pix01:       db  04,  10, 05,  11, 04,  12, 03,  13, 02,  00, 00,  00, 00,  00, 00
;Pix01_02:    db  05,  10, 05,  11, 05,  12, 04,  13, 03,  14, 02,  00, 00,  00, 00
;Pix02:       db  06,  10, 06,  11, 05,  12, 05,  13, 04,  14, 04,  15, 03,  00, 00
;Pix02_03:    db  07,  10, 06,  11, 06,  12, 05,  13, 05,  14, 05,  15, 05,  16, 05  
;Pix03:       db  07,  10, 06,  11, 06,  12, 06,  13, 06,  14, 06,  15, 06,  16, 06
;Pix03_04:    db  07,  10, 06,  11, 06,  12, 07,  13, 07,  14, 07,  15, 07,  16, 07
;Pix04:       db  06,  10, 06,  11, 07,  12, 07,  13, 08,  14, 08,  15, 09,  00, 00
;Pix04_05:    db  05,  10, 07,  11, 07,  12, 08,  13, 09,  14, 10,  00, 00,  00, 00
;Pix05:       db  04,  10, 07,  11, 08,  12, 09,  13, 10,  00, 00,  00, 00,  00, 00 
;Pix05_06:    db  04,  09, 07,  10, 08,  10, 09,  11, 10,  00, 00,  00, 00,  00, 00
;Pix06:       db  04,  09, 07,  09, 08,  09, 09,  09, 10,  00, 00,  00, 00,  00, 00
;Pix06_07:    db  04,  09, 07,  08, 08,  08, 09,  07, 10,  00, 00,  00, 00,  00, 00
;Pix07:       db  04,  08, 07,  07, 08,  06, 09,  05, 10,  00, 00,  00, 00,  00, 00 
;Pix07_08:    db  05,  08, 07,  07, 07,  06, 08,  05, 09,  04, 10,  00, 00,  00, 00
;Pix08:       db  06,  08, 06,  07, 07,  06, 07,  05, 08,  04, 08,  03, 09,  00, 00
;Pix08_09:    db  07,  08, 06,  07, 06,  06, 07,  05, 07,  04, 07,  03, 07,  02, 07
;Pix09:       db  07,  08, 06,  07, 06,  06, 06,  05, 06,  04, 06,  03, 06,  02, 06
;Pix09_10:    db  07,  08, 06,  07, 06,  06, 05,  05, 05,  04, 05,  03, 05,  02, 05
;Pix10:       db  06,  08, 06,  07, 05,  06, 05,  05, 04,  04, 04,  03, 03,  00, 00
;Pix10_11:    db  05,  08, 05,  07, 05,  06, 04,  05, 03,  04, 02,  00, 00,  00, 00
;Pix11:       db  04,  08, 05,  07, 04,  06, 03,  05, 02,  00, 00,  00, 00,  00, 00
;Pix11_00:    db  04,  09, 05,  08, 04,  08, 03,  07, 02,  00, 00,  00, 00,  00, 00



Pix00:       db 4H,  73H, 72H, 71H,  70H,  00H,  00H,  00H
Pix00_01:    db 4H,  73H, 82H, 81H,  90H,  00H,  00H,  00H
Pix01:       db 4H,  83H, 92H, 0A1H, 0B0H, 00H,  00H,  00H
Pix01_02:    db 5H,  83H, 93H, 0A2H, 0B1H, 0C0H, 00H,  00H
Pix02:       db 6H,  84H, 93H, 0A3H, 0B2H, 0C2H, 0D1H, 00H
Pix02_03:    db 7H,  84H, 94H, 0A3H, 0B3H, 0C3H, 0D3H, 0E3H
Pix03:       db 7H,  84H, 94H, 0A4H, 0B4H, 0C4H, 0D4H, 0E4H
Pix03_04:    db 7H,  84H, 94H, 0A5H, 0B5H, 0C5H, 0D5H, 0E5H
Pix04:       db 6H,  84H, 95H, 0A5H, 0B6H, 0C6H, 0D7H, 00H
Pix04_05:    db 5H,  85H, 95H, 0A6H, 0B7H, 0C8H, 00H,  00H
Pix05:       db 4H,  85H, 96H, 0A7H, 0B8H, 00H,  00H,  00H
Pix05_06:    db 4H,  75H, 86H, 87H,  98H,  00H,  00H,  00H
Pix06:       db 4H,  75H, 76H, 77H,  78H,  00H,  00H,  00H
Pix06_07:    db 4H,  75H, 66H, 67H,  58H,  00H,  00H,  00H
Pix07:       db 4H,  65H, 56H, 47H,  38H,  00H,  00H,  00H
Pix07_08:    db 5H,  65H, 55H, 46H,  37H,  28H,  00H,  00H
Pix08:       db 6H,  64H, 55H, 45H,  36H,  26H,  17H,  00H
Pix08_09:    db 7H,  64H, 54H, 45H,  35H,  25H,  15H,  05H
Pix09:       db 7H,  64H, 54H, 44H,  34H,  24H,  14H,  04H
Pix09_10:    db 7H,  64H, 54H, 43H,  33H,  23H,  13H,  03H
Pix10:       db 6H,  64H, 53H, 43H,  32H,  22H,  11H,  00H
Pix10_11:    db 5H,  63H, 53H, 42H,  31H,  20H,  00H,  00H
Pix11:       db 4H,  63H, 52H, 41H,  30H,  00H,  00H,  00H
Pix11_00:    db 4H,  73H, 62H, 61H,  50H  ;, 00H, 00H, 00H







                
