;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File Name    : mwaBigAnalog.asm
; Purpose      : MyWatch Application Big ananlog watch
; Version      : 2.10
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;DO NOT MODIFY THE FOLLOWING SUBROUTINE DEFINITION;;;;;;;;;;;;;;;;;

                IF @DEF('SUBROUTINE')
                    UNDEF SUBROUTINE
                ENDIF
                DEFINE  SUBROUTINE      "'mwabiganalog'"
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Module Name : mwaBigAnlogStateManager
; Description : MyWatch Application big analog State Manager.
; Assumptions : Display is cleared on first time entry into the state.
; Input(s)    : CORECurrentEvent  - system event to be processed
;               COREEventArgument - event extra information
; Output(s)   : None
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

                GLOBAL  mwaBigAnalogStateManager

mwaBigAnalogStateManager:

                ; Set IYReg the address of the MyWatch ASD.
                ;ld      IY, [CORECurrentASDAddress]

                ld      A, [CORECurrentEvent]

                ; Check if state entry event.
                cp      A, #MWA_STATEENTRY
                jr      Z, mwaStateEntryEvent

                ; Check if mode depress event.
                cp      A, #MWA_MODEDEPRESS
                jr      Z, mwaModeDepressEvent

                ; Check if start/split depress event.
                cp      A, #MWA_STARTDEPRESS
                jr      Z, mwaStartDepressEvent

                ; Check if stop/reset depress event.
                cp      A, #MWA_STOPDEPRESS
                jr      Z, mwaStopDepressEvent
                
                ; Check if crown set event.
                cp      A, #MWA_CROWNSET
                jr      Z, mwaPulledCrownEvent

                ; Check if TOD display update event
                cp      A,#MWA_UPDATE_TODRES
                jr      Z,mwaUpdateTODResEvent
                
                ; Check if crown CW event.
                cp      A,#MWA_CWPULSES
                jr      Z,mwaCWEvent
                
                ; Check if crown CCW event.
                cp      A,#MWA_CCWPULSES
                jr      Z,mwaCCWEvent
                
                ret
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;; EVENT HANDLERS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


mwaModeDepressEvent:
                ;**************************************************************
                ;
                ;                       MODE DEPRESS
                ;
                ;**************************************************************

                ;This is default to go to the next mode
                CORE_REQ_MODE_CHANGE_NEXT
                ret


mwaStartDepressEvent:
                ;**************************************************************
                ;
                ;                       START DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTARTSTATE
                CORE_REQ_STATE_CHANGE
                ret


mwaStopDepressEvent:
                ;**************************************************************
                ;
                ;                       STOP DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTOPSTATE
                CORE_REQ_STATE_CHANGE
                ret
                

mwaPulledCrownEvent:
                ;**************************************************************
                ;
                ;                       CROWN SET
                ;
                ;**************************************************************

                ld      B, #CORESTATE2
                CORE_REQ_STATE_CHANGE
                ret


mwaCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CW
                ;
                ;**************************************************************

                ld      A, #CMD_NEXT
                jr      GotoState1
                ;ld      [MWA_Command],A
                ;ld      B, #CORESTATE1
                ;CORE_REQ_STATE_CHANGE

                ;ret

mwaCCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CCW
                ;
                ;**************************************************************

                ld      A, #CMD_PREV

                ;-- Jump to State1 and request the next or prev watch --
GotoState1:                
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE
                ret


mwaStateEntryEvent:
                ;**************************************************************
                ;
                ;                       STATE ENTRY
                ;
                ;**************************************************************

                car     DisplayLockFlag

                ; Enable pulse mode
                CORE_ENABLE_PULSE_MODE
                
                ;-- Display --
                car     ReadLocalTime
                car     Redraw
                ;car     DisplayDateInSegment
                ;car     DisplayCustomDOW
                ;car     DisplayEmptyWatch
                ;car     DisplayAnalogTime

                ;-- Enable seconds updates from the primary time zone resource
                ld      A, [COREPTZIndex]
                KTOD_ENABLE_DISP_UPD_SEC_EVENT
                
                ret


mwaUpdateTODResEvent:
                ;**************************************************************
                ;
                ;                       UPDATE TOD RESSOURCE (1s)
                ;
                ;**************************************************************

                ;Get the current update status flag of the primary time zone resource
                car     ReadLocalTime

                ld      A, [COREPTZIndex]
                KTOD_GET_UPDATE_FLAGS
                bit     A,#bKTODMinuteUpd
                jr      Z,lbUpdate1
                  car     Redraw
                  car     TestRandomMode
                  ;car     DisplayDateInSegment
                  ;car     DisplayCustomDOW
                  ;car     DisplayEmptyWatch
                  ;car     DisplayAnalogTime
lbUpdate1:        
                ;Invert the center pixel   
                ld      HL,#0FA16H
                xor     [HL],#01
                Ret

 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; FUNCTIONS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;-- Redraw the full Display
Redraw:       
                  car     DisplayDateInSegment
                  car     DisplayCustomDOW
                  car     DisplayEmptyWatch
                  car     DisplayAnalogTime
                  ret



;-- Display empty Watch
DisplayEmptyWatch:
                ;First line
                ld  B, #23
                ld  IY,#WatchLine1
                ld  IX, #0F90BH
                UTL_COPY_IYREG_TO_IXREG
                
                ;Second Line
                ld  B, #23
                ld  IY,#WatchLine2
                ld  IX, #0FA0BH
                UTL_COPY_IYREG_TO_IXREG
                Ret          

;-- Display the analog time    
DisplayAnalogTime:
                ;-- Minute display
                ld    A,[dTODMin]
                UTL_CONVERT_1BYTE_BCD_TO_1BYTE_HEX
                ld    H,#0
                ld    L,A
                ld    A,#5
                div         ;L=HL/A
                push  L

                ld    A,#19
                mlt         ;HL=L*A
                
                ld    IX,#Pix00
                add   IX,HL
                
                ld    B,[IX]
                ;ld    B,[IX+L]
                inc   IX
                car   DispAnalog
                
                ;-- Hour display
                ld    A,[dTODHour]
                UTL_CONVERT_1BYTE_BCD_TO_1BYTE_HEX
                ld    H,#0
                ld    L,A
                ld    A,#12
                div         ;L=HL/A H=remainder
                ld    L,H
                
                pop   A
                cp    A,#6
                jrs   LE,DispAnalogL1
                  inc L
                  cp  L,#12
                  jr  NZ,DispAnalogL1
                    ld  L,#0 
DispAnalogL1:
                ld    A,#19
                mlt         ;HL=L*A
                
                ld    IX,#Pix00
                add   IX,HL
                
                ld    B,[IX]
                ;ld    B,[IX+L]
                dec   B
                inc   IX
                car   DispAnalog
                
                ret                

                
DispAnalog:                
                ;-- B  : Number of data to read
                ;-- IX : Address of the first data
lbLoopDispAnalog:
                push  B

                ld    A,[IX]
                inc   IX
                ld    B,[IX]
                
                ; Turn on Pixel (x = A, y = B)
                LCD_DISPLAY_MAIN_DM_PIXEL
                inc   IX
                
                pop   B
                DJR   NZ,lbLoopDispAnalog
                      
                Ret


                
                
                
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; DATAS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


WatchLine1:
db 00H,04H,04H,00H,00H,01H,01H,00H,00H,00H,00H,01H,00H,00H,00H,00H,01H,01H,00H,00H,04H,04H,00H
WatchLine2:
db 01H,09H,08H,00H,00H,20H,20H,00H,00H,00H,00H,21H,00H,00H,00H,00H,20H,20H,00H,00H,08H,09H,01H

;-- Analog display (pixel datas)
Pix00:       db  4, 21,05,  21,04,  21,03,  21,02,  00,00,  00,00, 00,00, 00,00, 00,00
Pix01:       db  4, 22,05,  23,04,  24,03,  25,02,  00,00,  00,00, 00,00, 00,00, 00,00
Pix02:       db  8, 22,06,  23,05,  24,05,  25,05,  26,04,  27,04, 28,04, 29,03, 00,00
Pix03:       db  9, 22,06,  23,06,  24,06,  25,06,  26,06,  27,06, 28,06, 29,06, 30,06
Pix04:       db  8, 22,06,  23,07,  24,07,  25,07,  26,08,  27,08, 28,08, 29,09, 00,00
Pix05:       db  4, 22,07,  23,08,  24,09,  25,10,  00,00,  00,00, 00,00, 00,00, 00,00
Pix06:       db  4, 21,07,  21,08,  21,09,  21,10,  00,00,  00,00, 00,00, 00,00, 00,00
Pix07:       db  4, 20,07,  19,08,  18,09,  17,10,  00,00,  00,00, 00,00, 00,00, 00,00 
Pix08:       db  8, 20,06,  19,07,  18,07,  17,07,  16,08,  15,08, 14,08, 13,09, 00,00
Pix09:       db  9, 20,06,  19,06,  18,06,  17,06,  16,06,  15,06, 14,06, 13,06, 12,06
Pix10:       db  8, 20,06,  19,05,  18,05,  17,05,  16,04,  15,04, 14,04, 13,03, 00,00
Pix11:       db  4, 20,05,  19,04,  18,03,  17,02,  00,00,  00,00, 00,00, 00,00, 00,00








                
