;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File Name    : mwaDice.asm
; Purpose      : MyWatch Application Dice State Manager
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;DO NOT MODIFY THE FOLLOWING SUBROUTINE DEFINITION;;;;;;;;;;;;;;;;;

                IF @DEF('SUBROUTINE')
                    UNDEF SUBROUTINE
                ENDIF
                DEFINE  SUBROUTINE      "'mwaDice'"
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Module Name : mwaDiceStateManager
; Description : MyWatch Application Dice State Manager.
; Assumptions : Display is cleared on first time entry into the state.
; Input(s)    : CORECurrentEvent  - system event to be processed
;               COREEventArgument - event extra information
; Output(s)   : None
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

                GLOBAL  mwaDiceStateManager

mwaDiceStateManager:

                ; Set IYReg the address of the MyWatch ASD.
                ld      IY, [CORECurrentASDAddress]

                ld      A, [CORECurrentEvent]

                ; Check if state entry event.
                cp      A, #MWA_STATEENTRY
                jr      Z, mwaStateEntryEvent

                ; Check if mode depress event.
                cp      A, #MWA_MODEDEPRESS
                jr      Z, mwaModeDepressEvent

                ; Check if start/split depress event.
                cp      A, #MWA_STARTDEPRESS
                jr      Z, mwaStartDepressEvent

                ; Check if stop/reset depress event.
                cp      A, #MWA_STOPDEPRESS
                jr      Z, mwaStopDepressEvent
                
                ; Check if crown set event.
                cp      A, #MWA_CROWNSET
                jr      Z, mwaPulledCrownEvent

                ; Check if TOD display update event
                cp      A,#MWA_UPDATE_TODRES
                jr      Z,mwaUpdateTODResEvent
                
                ; Check if crown CW event.
                cp      A,#MWA_CWPULSES
                jr      Z,mwaCWEvent
                
                ; Check if crown CCW event.
                cp      A,#MWA_CCWPULSES
                jr      Z,mwaCCWEvent
                
                ret
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;; EVENT HANDLERS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


mwaModeDepressEvent:
                ;**************************************************************
                ;
                ;                       MODE DEPRESS
                ;
                ;**************************************************************

                ;This is default to go to the next mode

                CORE_REQ_MODE_CHANGE_NEXT

                ret


mwaStartDepressEvent:
                ;**************************************************************
                ;
                ;                       START DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTARTSTATE
                CORE_REQ_STATE_CHANGE
                ret


mwaStopDepressEvent:
                ;**************************************************************
                ;
                ;                       STOP DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTOPSTATE
                CORE_REQ_STATE_CHANGE
                ret
                

mwaPulledCrownEvent:
                ;**************************************************************
                ;
                ;                       CROWN SET
                ;
                ;**************************************************************

                ld      B, #CORESTATE2
                CORE_REQ_STATE_CHANGE

                ret

mwaCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CW
                ;
                ;**************************************************************

                ld      A, #CMD_NEXT
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE

                ret

mwaCCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CCW
                ;
                ;**************************************************************

                ld      A, #CMD_PREV
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE

                ret


mwaStateEntryEvent:
                ;**************************************************************
                ;
                ;                       STATE ENTRY
                ;
                ;**************************************************************

                car     DisplayLockFlag
                
                ; Enable pulse mode
                CORE_ENABLE_PULSE_MODE

                CORE_SET_RANDOM_SEED

                car     ReadLocalTime
                car     Redraw_Full
                car     FirstDraw

                ;-- Enable seconds updates from the primary time zone resource
                ld      A, [COREPTZIndex]
                KTOD_ENABLE_DISP_UPD_SEC_EVENT
                
                ret


mwaUpdateTODResEvent:
                ;**************************************************************
                ;
                ;                       UPDATE TOD RESSOURCE (1s)
                ;
                ;**************************************************************

                ;Get the current update status flag of the primary time zone resource
                car     ReadLocalTime

                ld      A, [COREPTZIndex]
                KTOD_GET_UPDATE_FLAGS
                bit     A,#bKTODMinuteUpd
                jr      Z,lbUpdate1
                  car     Redraw_Full
                  car     TestRandomMode
                  ret
lbUpdate1:                
                car     DisplayTime
                car     DisplayDice
                Ret

 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; FUNCTIONS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

Redraw_Full:
                car     DisplayDateInSegment
                car     DisplayCustomDOW
                car     DisplayTime
                car     DisplayDice
                ret


;-- Display 3 Dice
DisplayDice:
                ld      A,[Cmpt]  
                inc     A
                ld      [Cmpt],A  
                cp      A,#5
                jr      NZ,DisplayEnd
                  ld    A,#0
                  ld    [Cmpt],A  

FirstDraw:
                ;-- Dice 1 --
                car     Generate
                push    IY
                
                ld      B, #7
                ld      IX, #0F902H
                UTL_COPY_IYREG_TO_IXREG    

                pop     IY
                add     IY,#7                
                ld      B, #7
                ld      IX, #0FA02H
                UTL_COPY_IYREG_TO_IXREG
                
                ;-- Dice 2 --
                car     Generate
                push    IY
                
                ld      B, #7
                ld      IX, #0F908H
                UTL_COPY_IYREG_TO_IXREG    

                pop     IY
                add     IY,#7                
                ld      B, #7
                ld      IX, #0FA08H
                UTL_COPY_IYREG_TO_IXREG
                
                ;-- Dice 3 --
                car     Generate
                push    IY
                
                ld      B, #7
                ld      IX, #0F90EH
                UTL_COPY_IYREG_TO_IXREG    

                pop     IY
                add     IY,#7                
                ld      B, #7
                ld      IX, #0FA0EH
                UTL_COPY_IYREG_TO_IXREG
                
DisplayEnd:                
                Ret  
                
;-- Generate the random number and return the pointer to the pattern
; IY : Pointer to the pattern
Generate:
                CORE_GENERATE_RANDOM_NUMBER   ;Random number in A (0..255)
                LD      L,A
                LD      H,#0
                
                ld      A,#6
                div                           ;L=HL/A and H=Reminder                                
                
                ld      L,H
                ld      A,#14
                mlt                           ;HL=L*A
                
                ld      IY,#Dice1
                add     IY,HL
                ret       

;-- Display the digital time    
DisplayTime:
                ;-- Display hour                
                ld  A, [dTODHour]
                ld  IX, #LCDMAINDMLINE1COL22
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_SUP_ZERO_MSD

                ;-- Display Colon
                ld  L, #DM5_COLON
                ld  IX, #LCDMAINDMLINE1COL32
                LCD_DISP_SMALL_PROP_WIDTH_DM_CHAR
                
                ;-- Display minute
                ld  A, [dTODMin]
                ld  IX, #LCDMAINDMLINE1COL34
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP
                
                ;-- Display second
                ld  A, [dTODSec]
                ld  IX, #LCDMAINDMLINE2COL34
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP
                
                Ret

                
                
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; DATAS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
Cmpt:           db 0  ;Number of second between 2 generation

Dice1:          db 1CH,02H,02H,02H,02H,02H,1CH
                db 0FH,10H,10H,11H,10H,10H,0FH
Dice2:          db 1CH,02H,02H,02H,02H,02H,1CH
                db 0FH,10H,11H,10H,11H,10H,0FH
Dice3:          db 1CH,02H,02H,0AH,02H,02H,1CH
                db 0FH,10H,10H,15H,10H,10H,0FH
Dice4:          db 1CH,02H,0AH,02H,0AH,02H,1CH
                db 0FH,10H,14H,10H,14H,10H,0FH
Dice5:          db 1CH,02H,0AH,02H,0AH,02H,1CH
                db 0FH,10H,14H,11H,14H,10H,0FH
Dice6:          db 1CH,02H,0AH,02H,0AH,02H,1CH
                db 0FH,10H,15H,10H,15H,10H,0FH













                
