;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File Name    : mwabig.asm
; Purpose      : MyWatch Application big watch State Manager
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;DO NOT MODIFY THE FOLLOWING SUBROUTINE DEFINITION;;;;;;;;;;;;;;;;;

                IF @DEF('SUBROUTINE')
                    UNDEF SUBROUTINE
                ENDIF
                DEFINE  SUBROUTINE      "'mwabig'"
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Module Name : mwaBigStateManager
; Description : MyWatch Application big watch State Manager.
; Assumptions : Display is cleared on first time entry into the state.
; Input(s)    : CORECurrentEvent  - system event to be processed
;               COREEventArgument - event extra information
; Output(s)   : None
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

                GLOBAL  mwaBigStateManager

mwaBigStateManager:

                ; Set IYReg the address of the MyWatch ASD.
                ;ld      IY, [CORECurrentASDAddress]

                ld      A, [CORECurrentEvent]

                ; Check if state entry event.
                cp      A, #MWA_STATEENTRY
                jr      Z, mwaStateEntryEvent

                ; Check if mode depress event.
                cp      A, #MWA_MODEDEPRESS
                jr      Z, mwaModeDepressEvent

                ; Check if start/split depress event.
                cp      A, #MWA_STARTDEPRESS
                jr      Z, mwaStartDepressEvent

                ; Check if stop/reset depress event.
                cp      A, #MWA_STOPDEPRESS
                jr      Z, mwaStopDepressEvent
                
                ; Check if crown set event.
                cp      A, #MWA_CROWNSET
                jr      Z, mwaPulledCrownEvent

                ; Check if TOD display update event
                cp      A,#MWA_UPDATE_TODRES
                jr      Z,mwaUpdateTODResEvent
                
                ; Check if crown CW event.
                cp      A,#MWA_CWPULSES
                jr      Z,mwaCWEvent
                
                ; Check if crown CCW event.
                cp      A,#MWA_CCWPULSES
                jr      Z,mwaCCWEvent
                
                ret
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;; EVENT HANDLERS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


mwaModeDepressEvent:
                ;**************************************************************
                ;
                ;                       MODE DEPRESS
                ;
                ;**************************************************************

                ;This is default to go to the next mode

                CORE_REQ_MODE_CHANGE_NEXT

                ret


mwaStartDepressEvent:
                ;**************************************************************
                ;
                ;                       START DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTARTSTATE
                CORE_REQ_STATE_CHANGE
                ret


mwaStopDepressEvent:
                ;**************************************************************
                ;
                ;                       STOP DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTOPSTATE
                CORE_REQ_STATE_CHANGE
                ret
                

mwaPulledCrownEvent:
                ;**************************************************************
                ;
                ;                       CROWN SET
                ;
                ;**************************************************************

                ld      B, #CORESTATE2
                CORE_REQ_STATE_CHANGE

                ret

mwaCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CW
                ;
                ;**************************************************************

                ld      A, #CMD_NEXT
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE

                ret

mwaCCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CCW
                ;
                ;**************************************************************

                ld      A, #CMD_PREV
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE

                ret


mwaStateEntryEvent:
                ;**************************************************************
                ;
                ;                       STATE ENTRY
                ;
                ;**************************************************************

                car     DisplayLockFlag

                ; Enable pulse mode
                CORE_ENABLE_PULSE_MODE

                car     ReadLocalTime
                car     Redraw_Full
                ;car     DisplayDateInSegment
                ;car     DisplayCustomDOW
                ;car     DisplayHourMinute
                ;car     DisplaySecond

                ;-- Enable seconds updates from the primary time zone resource
                ld      A, [COREPTZIndex]
                KTOD_ENABLE_DISP_UPD_SEC_EVENT
                
                ret


mwaUpdateTODResEvent:
                ;**************************************************************
                ;
                ;                       UPDATE TOD RESSOURCE (1s)
                ;
                ;**************************************************************

                ;Get the current update status flag of the primary time zone resource
                car     ReadLocalTime

                ld      A, [COREPTZIndex]
                KTOD_GET_UPDATE_FLAGS
                bit     A,#bKTODMinuteUpd
                jr      Z,lbUpdate1
                  LCD_CLEAR_MAIN_DM
                  car     Redraw_Full
                  ;car     DisplayDateInSegment
                  ;car     DisplayCustomDOW
                  ;car     DisplayHourMinute
                  car     TestRandomMode
                  ret
lbUpdate1:                
                car     DisplaySecond
                
                Ret

 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; FUNCTIONS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

Redraw_Full:
                car     DisplayDateInSegment
                car     DisplayCustomDOW
                car     DisplayHourMinute
                car     DisplaySecond
                ret


;-- Display Second
DisplaySecond:
                ld    A,[dTODSec]
                upck
                push  A
                
                ld    L,B
                ld    IX, #LCDMAINDMLINE1COL39
                LCD_DISP_SMALL_PROP_WIDTH_DM_CHAR

                pop   L
                ld    IX, #LCDMAINDMLINE2COL39
                LCD_DISP_SMALL_PROP_WIDTH_DM_CHAR
                RET         


;-- Display HM big digit
DisplayHourMinute:
                ;## Display big hour ##
                ld    A,[dTODHour]
                upck  
                push  A

                cp    B,#0
                jr    Z,HML1

                push  B
                ;-- Digit 1 UP
                ex    A,B
                
                ld    L,#08
                mlt   ;HL=L*A

                ld    IY,#Dig0_1
                add   IY,HL
                ld    B, #8
                ld    IX, #0F902H
                UTL_COPY_IYREG_TO_IXREG   

                ;-- Digit 1 Down
                pop   A
                ld    L,#08
                mlt   ;HL=L*A

                ld    IY,#Dig0_2
                add   IY,HL
                ld    B, #8
                ld    IX, #0FA02H
                UTL_COPY_IYREG_TO_IXREG   
HML1:
                ;-- Digit 2 UP
                pop   A
                push  A
                
                ld    L,#08
                mlt   ;HL=L*A

                ld    IY,#Dig0_1
                add   IY,HL
                ld    B, #8
                ld    IX, #0F90BH
                UTL_COPY_IYREG_TO_IXREG   

                ;-- Digit 2 Down
                pop   A
                ld    L,#08
                mlt   ;HL=L*A

                ld    IY,#Dig0_2
                add   IY,HL
                ld    B, #8
                ld    IX, #0FA0BH
                UTL_COPY_IYREG_TO_IXREG   
                
                ;-- Display ":"
                LD    IY,#0F914H
                LD    A,#10H
                LD    [IY],A
                
                LD    IY,#0FA14H
                LD    A,#04H
                LD    [IY],A

                ;## Display big minute ##
                ld    A,[dTODMin]
                upck  
                push  A
                push  B
                ;-- Digit 3 UP
                ex    A,B
                
                ld    L,#08
                mlt   ;HL=L*A

                ld    IY,#Dig0_1
                add   IY,HL
                ld    B, #8
                ld    IX, #0F916H
                UTL_COPY_IYREG_TO_IXREG   

                ;-- Digit 3 Down
                pop   A
                ld    L,#08
                mlt   ;HL=L*A

                ld    IY,#Dig0_2
                add   IY,HL
                ld    B, #8
                ld    IX, #0FA16H
                UTL_COPY_IYREG_TO_IXREG   

                ;-- Digit 4 UP
                pop   A
                push  A
                
                ld    L,#08
                mlt   ;HL=L*A

                ld    IY,#Dig0_1
                add   IY,HL
                ld    B, #8
                ld    IX, #0F91FH
                UTL_COPY_IYREG_TO_IXREG   

                ;-- Digit 4 Down
                pop   A
                ld    L,#08
                mlt   ;HL=L*A

                ld    IY,#Dig0_2
                add   IY,HL
                ld    B, #8
                ld    IX, #0FA1FH
                UTL_COPY_IYREG_TO_IXREG   

                RET


                
                
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; DATAS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;-- Label for the configurator --
        db  'M','W','1','0','B'
;-- Top digit patterns
Dig0_1:         db 1EH,1FH,03H,03H,03H,03H,1FH,1EH
Dig1_1:         db 00H,08H,0CH,0EH,07H,1FH,1FH,1FH
Dig2_1:         db 06H,07H,03H,03H,13H,1BH,1FH,0EH
Dig3_1:         db 06H,07H,03H,13H,13H,13H,1FH,0EH
Dig4_1:         db 10H,18H,1CH,0EH,07H,03H,1FH,1FH
Dig5_1:         db 1FH,1FH,13H,13H,13H,13H,13H,03H
Dig6_1:         db 1EH,1FH,13H,13H,13H,13H,17H,06H
Dig7_1:         db 03H,03H,03H,03H,03H,13H,1FH,0FH
Dig8_1:         db 0EH,1FH,13H,13H,13H,13H,1FH,0EH
Dig9_1:         db 1EH,1FH,13H,13H,13H,13H,1FH,1EH

;-- Low digit patterns
Dig0_2:         db 1FH,3FH,30H,30H,30H,30H,3FH,1FH
Dig1_2:         db 00H,00H,00H,00H,00H,3FH,3FH,3FH
Dig2_2:         db 38H,3CH,3EH,37H,33H,31H,30H,30H
Dig3_2:         db 18H,38H,30H,31H,31H,31H,3FH,1EH
Dig4_2:         db 03H,03H,03H,03H,03H,03H,3FH,3FH
Dig5_2:         db 19H,39H,31H,31H,31H,31H,3FH,1FH
Dig6_2:         db 1FH,3FH,31H,31H,31H,31H,3FH,1FH
Dig7_2:         db 00H,00H,3CH,3EH,03H,01H,00H,00H
Dig8_2:         db 1EH,3FH,31H,31H,31H,31H,3FH,1EH
Dig9_2:         db 18H,39H,31H,31H,31H,31H,3FH,1FH





;Dig1_Up F902
;Dig1_Dn FA02

;Dig2_Up F90B
;Dig2_Dn FA0B

;Dig3_Up F916
;Dig3_Dn FA16

;Dig4_Up F91F
;Dig4_Dn FA1F

;db 00,00,00



                
