;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File Name    : mwavbin.asm
; Purpose      : MyWatch Application big binary State Manager
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;DO NOT MODIFY THE FOLLOWING SUBROUTINE DEFINITION;;;;;;;;;;;;;;;;;

                IF @DEF('SUBROUTINE')
                    UNDEF SUBROUTINE
                ENDIF
                DEFINE  SUBROUTINE      "'mwabigbin'"
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Module Name : mwaBigBinaryStateManager
; Description : MyWatch Application big binary State Manager.
; Assumptions : Display is cleared on first time entry into the state.
; Input(s)    : CORECurrentEvent  - system event to be processed
;               COREEventArgument - event extra information
; Output(s)   : None
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

                GLOBAL  mwaBigBinaryStateManager

mwaBigBinaryStateManager:

                ; Set IYReg the address of the MyWatch ASD.
                ld      IY, [CORECurrentASDAddress]

                ld      A, [CORECurrentEvent]

                ; Check if state entry event.
                cp      A, #MWA_STATEENTRY
                jr      Z, mwaStateEntryEvent

                ; Check if mode depress event.
                cp      A, #MWA_MODEDEPRESS
                jr      Z, mwaModeDepressEvent

                ; Check if start/split depress event.
                cp      A, #MWA_STARTDEPRESS
                jr      Z, mwaStartDepressEvent

                ; Check if stop/reset depress event.
                cp      A, #MWA_STOPDEPRESS
                jr      Z, mwaStopDepressEvent
                
                ; Check if crown set event.
                cp      A, #MWA_CROWNSET
                jr      Z, mwaPulledCrownEvent

                ; Check if TOD display update event
                cp      A,#MWA_UPDATE_TODRES
                jr      Z,mwaUpdateTODResEvent
                
                ; Check if crown CW event.
                cp      A,#MWA_CWPULSES
                jr      Z,mwaCWEvent
                
                ; Check if crown CCW event.
                cp      A,#MWA_CCWPULSES
                jr      Z,mwaCCWEvent
                
                ret
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;; EVENT HANDLERS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


mwaModeDepressEvent:
                ;**************************************************************
                ;
                ;                       MODE DEPRESS
                ;
                ;**************************************************************

                ;This is default to go to the next mode

                CORE_REQ_MODE_CHANGE_NEXT

                ret


mwaStartDepressEvent:
                ;**************************************************************
                ;
                ;                       START DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTARTSTATE
                CORE_REQ_STATE_CHANGE
                ret


mwaStopDepressEvent:
                ;**************************************************************
                ;
                ;                       STOP DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTOPSTATE
                CORE_REQ_STATE_CHANGE
                ret
                

mwaPulledCrownEvent:
                ;**************************************************************
                ;
                ;                       CROWN SET
                ;
                ;**************************************************************

                ld      B, #CORESTATE2
                CORE_REQ_STATE_CHANGE

                ret

mwaCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CW
                ;
                ;**************************************************************

                ld      A, #CMD_NEXT
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE

                ret

mwaCCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CCW
                ;
                ;**************************************************************

                ld      A, #CMD_PREV
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE

                ret


mwaStateEntryEvent:
                ;**************************************************************
                ;
                ;                       STATE ENTRY
                ;
                ;**************************************************************

                car     DisplayLockFlag

                ; Enable pulse mode
                CORE_ENABLE_PULSE_MODE

                car     ReadLocalTime
                car     Redraw_Full
                ;car     DisplayHMBinWatch
                ;car     DisplaySBinWatch
                ;car     DisplaySegment
                ;car     DisplayCustomDOW

                ;-- Enable seconds updates from the primary time zone resource
                ld      A, [COREPTZIndex]
                KTOD_ENABLE_DISP_UPD_SEC_EVENT
                
                ret


mwaUpdateTODResEvent:
                ;**************************************************************
                ;
                ;                       UPDATE TOD RESSOURCE (1s)
                ;
                ;**************************************************************

                ;Get the current update status flag of the primary time zone resource
                car     ReadLocalTime

                ld      A, [COREPTZIndex]
                KTOD_GET_UPDATE_FLAGS
                bit     A,#bKTODMinuteUpd
                jr      Z,lbUpdate1
                  ;car     DisplayHMBinWatch
                  ;car     DisplaySegment
                  ;car     DisplayCustomDOW
                  car     Redraw_Full
                  car     TestRandomMode
                  ret
lbUpdate1:                
                car     DisplaySBinWatch
                
                Ret

 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; FUNCTIONS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

Redraw_Full:
                car     DisplayHMBinWatch
                car     DisplaySegment
                car     DisplayCustomDOW
                car     DisplaySBinWatch
                ret


;-- Display the segment content --
DisplaySegment:
                ld      IY, [CORECurrentASDAddress]
                ld      A,[IY+MWA_OPTIONS]
                bit     A,#bOPTIONS_SEG_BIGBIN
                jr      NZ,DisplayDate          
                  car     DisplayTimeInSeg
                  ret
DisplayDate:
                car     DisplayDateInSegment
                ret
 
 
;-- Display S binary Watch
DisplaySBinWatch:
                ;== Minute ==               
                ld    A,[dTODSec]
                upck  
                
                push  A
                
                ;Display Sec (*10)
                ex    A,B
                
                ld    IX,#0F921H  ;20                
                car   Display_D3
                
                ;Display Sec (*1)
                pop   A
                ld    IX,#0F927H                 
                car   Display_D4

                RET         


;-- Display HM binary Watch
DisplayHMBinWatch:
                ld    A,[dTODHour]
                upck  
                
                push  A
                
                ;Display Hour (*10)
                ex    A,B
                
                ld    L,#05
                mlt   ;HL=L*A

                ld    IY,#D2_0
                add   IY,HL
                ld    B, #5
                ld    IX, #0FA02H
                UTL_COPY_IYREG_TO_IXREG 
                
                ;Display Hour (*1)
                pop   A
                ld    IX,#0F908H ;09                  
                car   Display_D4
                
                ;Display the colon
                LD  IY,#0FA0EH ;0F
                LD  A,#09H
                LD  [IY],A

                ;== Minute ==               
                ld    A,[dTODMin]
                upck  
                
                push  A
                
                ;Display Min (*10)
                ex    A,B
                
                ld    IX,#0F911H                  
                car   Display_D3
                
                ;Display Min (*1)
                pop   A
                ld    IX,#0F917H  ;18               
                car   Display_D4
                
                ;Display the colon
                LD    IY,#0FA1EH
                LD    A,#09H
                LD    [IY],A
                RET

;-- Display 4 bits number --------------------
;-- A=number to display  IX=display address --
Display_D4:
                push  IX
                ld    L,#10
                mlt   ;HL=L*A

                ld    IY,#D4_0_H
                add   IY,HL
                ld    B, #5
                UTL_COPY_IYREG_TO_IXREG 

                pop   IX
                add   IX,#100H
                ld    IY,#D4_0_B
                add   IY,HL
                ld    B, #5
                UTL_COPY_IYREG_TO_IXREG
                 
                ret

;-- Display 3 bits number --------------------
;-- A=number to display  IX=display address --
Display_D3:
                push  IX
                ld    L,#10
                mlt   ;HL=L*A

                ld    IY,#D3_0_H
                add   IY,HL
                ld    B, #5
                UTL_COPY_IYREG_TO_IXREG 

                pop   IX
                add   IX,#100H
                ld    IY,#D3_0_B
                add   IY,HL
                ld    B, #5
                UTL_COPY_IYREG_TO_IXREG
                 
                ret

;-- Display the Time in segment --
DisplayTimeInSeg:
                ld      A,[dTODMin]
                LD      IX, #LCDSEGDIGIT5
                LCD_DISP_2DIG_SEG_DATA_NO_ZERO_SUP
        
                ld      A,[dTODHour]
                LD      IX, #LCDSEGDIGIT3
                ;LCD_DISP_2DIG_SEG_DATA_NO_ZERO_SUP
                LCD_DISP_2DIG_SEG_DATA_SUP_ZERO_MSD
                
                LCD_UPD_COLON2_FLAG ON
                
                ret
                
                              
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; DATAS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

D2_0:   db 00H,00H,36H,00H,00H
D2_1:   db 30H,30H,36H,30H,30H
D2_2:   db 06H,06H,36H,06H,06H

D4_0_H: db 00H,00H,1BH,00H,00H
D4_0_B: db 00H,00H,36H,00H,00H
D4_1_H: db 00H,00H,1BH,00H,00H
D4_1_B: db 30H,30H,36H,30H,30H
D4_2_H: db 00H,00H,1BH,00H,00H
D4_2_B: db 06H,06H,36H,06H,06H
D4_3_H: db 00H,00H,1BH,00H,00H
D4_3_B: db 36H,36H,36H,36H,36H
D4_4_H: db 18H,18H,1BH,18H,18H
D4_4_B: db 00H,00H,36H,00H,00H
D4_5_H: db 18H,18H,1BH,18H,18H
D4_5_B: db 30H,30H,36H,30H,30H
D4_6_H: db 18H,18H,1BH,18H,18H
D4_6_B: db 06H,06H,36H,06H,06H
D4_7_H: db 18H,18H,1BH,18H,18H
D4_7_B: db 36H,36H,36H,36H,36H
D4_8_H: db 03H,03H,1BH,03H,03H
D4_8_B: db 00H,00H,36H,00H,00H
D4_9_H: db 03H,03H,1BH,03H,03H
D4_9_B: db 30H,30H,36H,30H,30H

D3_0_H: db 00H,00H,18H,00H,00H
D3_0_B: db 00H,00H,36H,00H,00H
D3_1_H: db 00H,00H,18H,00H,00H
D3_1_B: db 30H,30H,36H,30H,30H
D3_2_H: db 00H,00H,18H,00H,00H
D3_2_B: db 06H,06H,36H,06H,06H
D3_3_H: db 00H,00H,18H,00H,00H
D3_3_B: db 36H,36H,36H,36H,36H
D3_4_H: db 18H,18H,18H,18H,18H
D3_4_B: db 00H,00H,36H,00H,00H
D3_5_H: db 18H,18H,18H,18H,18H
D3_5_B: db 30H,30H,36H,30H,30H





                
