;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File Name    : mwadef.asm
; Purpose      : MyWatch Application Default State Manager
; Version      : 2.10
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;DO NOT MODIFY THE FOLLOWING SUBROUTINE DEFINITION;;;;;;;;;;;;;;;;;

                IF @DEF('SUBROUTINE')
                    UNDEF SUBROUTINE
                ENDIF
                DEFINE  SUBROUTINE      "'mwadef'"
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Module Name : mwaDefaultStateManager
; Description : MyWatch Application Default State Manager.
; Assumptions : Display is cleared on first time entry into the state.
; Input(s)    : CORECurrentEvent  - system event to be processed
;               COREEventArgument - event extra information
; Output(s)   : None
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

                GLOBAL  mwaDefaultStateManager

mwaDefaultStateManager:

                ; Set IYReg the address of the MyWatch ASD.
                ld      IY, [CORECurrentASDAddress]

                ld      A, [CORECurrentEvent]

                ; Check if state entry event.
                cp      A, #MWA_STATEENTRY
                jr      Z, mwaStateEntryEvent
                
                ret
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



mwaStateEntryEvent:
                ;**************************************************************
                ;
                ;                       STATE ENTRY
                ;
                ;**************************************************************
                

                ;-- Set the number watch in the ASD
                ld      A,[NbWatch]
                ld      [IY + MWA_NBWATCH],A
                
                ld      A,[MWA_Command]

                ;Check if Next watch request
                cp      A,#CMD_NEXT
                jr      Z,mwa_NEXT
                
                ;Check if Prev watch request
                cp      A,#CMD_PREV
                jr      Z,mwa_PREV
                
                cp      A,#CMD_INIT
                jr      NZ,Jump
                  ;-- Initialize the random generator
                  CORE_SET_RANDOM_SEED
                
                ;-- Default OR JUMP request --
Jump:
                ld      L,[IY + MWA_ACTIVE_WATCH]
                
                ld      IX,#OrderTab
                ld      B,[IX+L]

                CORE_REQ_STATE_CHANGE
                                
                ret

;== "NEXT" Request =============================================================
mwa_NEXT:
                ld      A,[IY + MWA_ACTIVE_WATCH]
                inc     A
                cp      A,[NbWatch]
                jr      NZ,L1_NEXT                
                  ld    A,#00
L1_NEXT:
                jr      Test_Lock


;== "PREV" Request =============================================================
mwa_PREV:
                ld      A,[IY + MWA_ACTIVE_WATCH]
                dec     A
                cp      A,#255
                jr      NZ,L1_PREV                
                  ld    A,[NbWatch]
                  dec   A
L1_PREV:

; W A R N I N G !!! This is a fall through.  Do not rearrange.


;== "LOCK" Test ================================================================                
; Test if the lock bit is set
; NO  : Store the new watch number in MWA_ACTIVE_WATCH and jump to the watch state
; YES : Don't store the new watch number and  nothing and jump to the watch state
 
Test_Lock:
                ld      B,A
                
                ld      A,[IY+MWA_OPTIONS]
                bit     A,#bOPTIONS_LOCK
                jr      NZ,No_Change_State ;-- Lock                    
                  ld      [IY + MWA_ACTIVE_WATCH], B
                
No_Change_State:
                jr      Jump

                
                
;=== DATA ======================================================================

;-- Label for the configurator --
                db  'M','W','1','0','D'
        
; -- Major version number, minor version number        
Version:         DB  2,2   
; -- Number of watch state
NbWatch:        DB  10     
; -- Watch state order when CW or CCW is used (each number is a state number)
; Set from 7 (First watch state) to the maximum number of watch (even they are not selected)
OrderTab:       DB  7,8,9,10,11,12,13,14,15,16  
