;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File Name    : mwaset.asm
; Purpose      : MyWatch Application Set State Manager
; Copyright Pierre Delore
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;DO NOT MODIFY THE FOLLOWING SUBROUTINE DEFINITION;;;;;;;;;;;;;;;;;

                IF @DEF('SUBROUTINE')
                    UNDEF SUBROUTINE
                ENDIF
                DEFINE  SUBROUTINE      "'mwaset'"
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

                GLOBAL  mwaSetStateManager

mwaSetStateManager:

                ld      A, [CORECurrentEvent]

                ; Check if state entry event.
                cp      A, #MWA_STATEENTRY
                jr      Z, mwaStateEntryEvent

                ; Check if start/split depress event.
                cp      A, #MWA_STARTDEPRESS
                jr      Z, mwaStartDepressEvent

                ; Check if stop/reset depress event.
                cp      A, #MWA_STOPDEPRESS
                jr      Z, mwaStopDepressEvent
                
                ; Check if crown is pulled
                cp      A, #MWA_CROWNHOME
                jr      Z, mwaPushedCrownEvent
                
                ret

;-------------------------------------------------------------------------------                

                
;--- Called at the entry of the state ---                
mwaStateEntryEvent:                
                
                ;-- Display the version --
;                ld    IY, #MsgVersion
;                LCD_DISP_SEG_LINE_MSG
;                LCD_UPD_PER2_FLAG ON

;------------------------------------------------------------------------------
;
; W A R N I N G !!! This is a fall through.  Do not rearrange.
;
;------------------------------------------------------------------------------                


;--- Called when STOP/RESET is pressed ---     
mwaStopDepressEvent:
                ;-- Inc 'OptNum'
                ld      A,[OptNum]
                inc     A
                cp      A,#5    ;Max value+1
                jr      NZ,StopL1
                  ld      B, #CORESTATE3
                  CORE_REQ_STATE_CHANGE
                  ret
                  ;ld    A,#1
StopL1:
                ld      [OptNum],A
                
                ;-- Display Option 1 ?
                cp      A,#1
                jr      NZ,StopL2
                  car   DISP_CST_OPTION1  
                  car   DISP_OPTION1
                  ret
StopL2:         
                ;-- Display Option 2 ?
                cp      A,#2
                jr      NZ,StopL3
                  car   DISP_CST_OPTION2  
                  car   DISP_OPTION2
                  ret
StopL3:                  
                ;-- Display Option 3 ?
                cp      A,#3
                jr      NZ,StopL4
                  car   DISP_CST_OPTION3  
                  car   DISP_OPTION3
                  ret            
StopL4:                  
                ;-- Display Option 4 ?
                cp      A,#4
                jr      NZ,StopL5
                  car   DISP_CST_OPTION4  
                  car   DISP_OPTION4
                  ret            
StopL5:                  
                          
                ret


;--- Called when START/SPLIT is pressed ---     
mwaStartDepressEvent:
                ld      IY, [CORECurrentASDAddress]
                ld      A,[IY+MWA_OPTIONS]
                
                ld      B,[OptNum]
                
                ;-- Option 1 ?
                cp      B,#1
                jr      NZ,StartL2
                  xor   A,#bOPTIONS_LOCK
                  ld    [IY+MWA_OPTIONS],A
                  car   DISP_OPTION1
                  ret
StartL2:         
                ;-- Display Option 2 ?
                cp      B,#2
                jr      NZ,StartL3
                  xor   A,#bOPTIONS_SOUND10
                  ld    [IY+MWA_OPTIONS],A
                  car   DISP_OPTION2
                  ret
StartL3:
                ;-- Display Option 3 ?
                cp      B,#3
                jr      NZ,StartL4
                  xor   A,#bOPTIONS_SEG_BIGBIN
                  ld    [IY+MWA_OPTIONS],A
                  car   DISP_OPTION3
                  ret
StartL4:           
                ;-- Display Option 4 ?
                cp      B,#4
                jr      NZ,StartL5

                  ;-- Reset the Time zone 
                  ld    B,A                  
                  and   A,#MWA_OPTIONS_TZONE_NEGMASK
                
                  ; incremente the time zone
                  and     B,#MWA_OPTIONS_TZONE_MASK                  
                  inc     B
                  cp      B,#3
                  jr      NZ,L4_1
                    ld    B,#0
L4_1:
                  or      A,B
                  ld    [IY+MWA_OPTIONS],A
                  car   DISP_OPTION4
                  ret
StartL5:           
     
                ret

                
;--- Called if the crown is pulled --- 
mwaPushedCrownEvent:
                ld      IY, [CORECurrentASDAddress]

                ld      A, #CMD_JUMP
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE
                                
                ret           

;-------------------------------------------------------------------------------                
; OPTION 1 : LOCK/UNLOCK DISPLAY
;-------------------------------------------------------------------------------                                               
DISP_CST_OPTION1:  
                LCD_CLR_DISPLAY
                
                ;-- Display the set number --
                ld      A, #01
                ld      IX, #LCDUPPERDMCOL1
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP
                
                ;-- Display the version --
                ld IY, #MsgVersion
                LCD_DISP_SEG_LINE_MSG
                LCD_UPD_PER2_FLAG ON

                ;-- Display DISPLAY --
                ld      IY, #MsgDisplay
                ld      IX, #LCDMAINDMLINE1COL1
                ld      B, #07
                LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG                             
                ret
                
                
;-------------------------------------------------------------------------------                
DISP_OPTION1:  
                LCD_CLR_MAIN_DM_LINE2
                ; Set IYReg the address of the MyWatch ASD.
                ld      IY, [CORECurrentASDAddress]
                ld      A,[IY+MWA_OPTIONS]
                bit     A,#bOPTIONS_LOCK
                jr      NZ,DisplayLock                                

                  ld      IY, #MsgUnlock
                  ld      IX, #LCDMAINDMLINE2COL1
                  ld      B, #06
                  LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG
                  ret
                  
DisplayLock:    
                ld      IY, #MsgLock
                ld      IX, #LCDMAINDMLINE2COL1
                ld      B, #04
                LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG                
                ret

;-------------------------------------------------------------------------------                
; OPTION 2 : SOUND MODE 10/15 minutes
;-------------------------------------------------------------------------------                                               
DISP_CST_OPTION2:     
                LCD_CLR_DISPLAY
                                          
                ld      A, #02
                ld      IX, #LCDUPPERDMCOL1
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP                               
                               
                ld      IY, #MsgSound
                ld      IX, #LCDMAINDMLINE1COL1
                ld      B, #06
                LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG               

                ld      IY, #MsgMode
                ld      IX, #LCDMAINDMLINE2COL1
                ld      B, #05
                LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG                
                ret        

;-------------------------------------------------------------------------------                
DISP_OPTION2:  
                ; Set IYReg the address of the MyWatch ASD.
                ld      IY, [CORECurrentASDAddress]
                ld      A,[IY+MWA_OPTIONS]
                bit     A,#bOPTIONS_SOUND10
                jr      NZ,Display10M                                
                  
                  ld    IY, #Msg15M
                  ld    IX, #LCDMAINDMLINE2COL24
                  ld    B, #03
                  LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG
                  ret
                  
Display10M:    
                  ld    IY, #Msg10M
                  ld    IX, #LCDMAINDMLINE2COL24
                  ld    B, #03
                  LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG
                ret

;-------------------------------------------------------------------------------                
; OPTION 3 : BIG BINARY SEGMENT DISPLAY : Time / Date
;-------------------------------------------------------------------------------                                               
DISP_CST_OPTION3:     
                LCD_CLR_DISPLAY
                                          
                ld      A, #03
                ld      IX, #LCDUPPERDMCOL1
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP                               
                               
                ld      IY, #MsgBigBin
                ld      IX, #LCDMAINDMLINE1COL1
                ld      B, #08
                LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG               

                ld      IY, #MsgSeg
                ld      IX, #LCDMAINDMLINE2COL1
                ld      B, #05
                LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG                
                ret        

;-------------------------------------------------------------------------------                
DISP_OPTION3:  
                ; Set IYReg the address of the MyWatch ASD.
                ld      IY, [CORECurrentASDAddress]
                ld      A,[IY+MWA_OPTIONS]
                bit     A,#bOPTIONS_SEG_BIGBIN
                jr      NZ,DisplayDate                                
                  
                  ld    IY, #MsgTime
                  ld    IX, #LCDMAINDMLINE2COL24
                  ld    B, #04
                  LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG
                  ret
                  
DisplayDate:    
                  ld    IY, #MsgDate
                  ld    IX, #LCDMAINDMLINE2COL24
                  ld    B, #04
                  LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG
                ret


;-------------------------------------------------------------------------------                
; OPTION 4 : DUAL DISPLAY : Zone 0,1,2
;-------------------------------------------------------------------------------                                               
DISP_CST_OPTION4:     
                LCD_CLR_DISPLAY
                                          
                ld      A, #04
                ld      IX, #LCDUPPERDMCOL1
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP                               
                               
                ld      IY, #MsgDualTime
                ld      IX, #LCDMAINDMLINE1COL1
                ld      B, #09
                LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG               

                ld      IY, #MsgZone
                ld      IX, #LCDMAINDMLINE2COL1
                ld      B, #05
                LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG                
                ret        

;-------------------------------------------------------------------------------                
DISP_OPTION4:  
                ; Set IYReg the address of the MyWatch ASD.
                ld      IY, [CORECurrentASDAddress]
                ld      A,[IY+MWA_OPTIONS]
                and     A,#MWA_OPTIONS_TZONE_MASK                  
                ld      IX, #LCDMAINDMLINE2COL24
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_SUP_ZERO_MSD  
                ret


                
                           
;-- DATAS ----------------------------------------------------------------------           
OptNum:         db 0

MsgVersion:     db SEG_SPACE, SEG_SPACE, SEG_V, SEG_2, SEG_2, SEG_1

MsgDisplay:     db DM5_D, DM5_I, DM5_S, DM5_P, DM5_L, DM5_A, DM5_Y
MsgUnlock:      db DM5_U, DM5_N, DM5_L, DM5_O, DM5_C, DM5_K
MsgLock:        db DM5_L, DM5_O, DM5_C, DM5_K

                
MsgSound:       db DM5_S, DM5_O, DM5_U, DM5_N, DM5_D, DM5_SPACE
MsgMode:        db DM5_M, DM5_O, DM5_D, DM5_E, DM5_COLON
Msg15M:         db DM5_1, DM5_5, DM5_M
Msg10M:         db DM5_1, DM5_0, DM5_M

MsgBigBin:      db DM5_B, DM5_I, DM5_G, DM5_SPACE, DM5_B, DM5_I, DM5_N, DM5_PERIOD
MsgSeg:         db DM5_S, DM5_E, DM5_G, DM5_PERIOD, DM5_COLON
MsgTime:        db DM5_T, DM5_I, DM5_M, DM5_E
MsgDate:        db DM5_D, DM5_A, DM5_T, DM5_E

MsgDualTime:    db DM5_D, DM5_U, DM5_A, DM5_L, DM5_SPACE, DM5_T, DM5_I, DM5_M, DM5_E
MsgZone:        db DM5_Z, DM5_O, DM5_N, DM5_E, DM5_COLON
