;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File Name    : mwaset2.asm
; Purpose      : MyWatch Application Second Set State Manager
; Copyright Pierre Delore
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;DO NOT MODIFY THE FOLLOWING SUBROUTINE DEFINITION;;;;;;;;;;;;;;;;;

                IF @DEF('SUBROUTINE')
                    UNDEF SUBROUTINE
                ENDIF
                DEFINE  SUBROUTINE      "'mwaset2'"
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

                GLOBAL  mwaSet2StateManager

mwaSet2StateManager:

                ld      A, [CORECurrentEvent]

                ; Check if state entry event.
                cp      A, #MWA_STATEENTRY
                jr      Z, mwaStateEntryEvent

                ; Check if start/split depress event.
                cp      A, #MWA_STARTDEPRESS
                jr      Z, mwaStartDepressEvent

                ; Check if stop/reset depress event.
                cp      A, #MWA_STOPDEPRESS
                jr      Z, mwaStopDepressEvent
                
                ; Check if crown is pulled
                cp      A, #MWA_CROWNHOME
                jr      Z, mwaPushedCrownEvent
                
                ret

;-------------------------------------------------------------------------------                

                
;--- Called at the entry of the state ---                
mwaStateEntryEvent:                
                
                ;-- Display the version --
;                ld    IY, #MsgVersion
;                LCD_DISP_SEG_LINE_MSG
;                LCD_UPD_PER2_FLAG ON

;------------------------------------------------------------------------------
;
; W A R N I N G !!! This is a fall through.  Do not rearrange.
;
;------------------------------------------------------------------------------                


;--- Called when STOP/RESET is pressed ---     
mwaStopDepressEvent:
                ;-- Inc 'OptNum'
                ld      A,[OptNum]
                inc     A
                cp      A,#2    ;Max value+1
                jr      NZ,StopL5
                  ld      B, #CORESTATE2
                  CORE_REQ_STATE_CHANGE
                  ret
                  ;ld    A,#1
                  
StopL5:  
                ld      [OptNum],A
                
                ;-- Display Option 5 ?
                cp      A,#1  ;Option - 4
                jr      NZ,StopL6
                  car   DISP_CST_OPTION5  
                  car   DISP_OPTION5
                  ret
StopL6:         

                          
                ret


;--- Called when START/SPLIT is pressed ---     
mwaStartDepressEvent:
                ld      IY, [CORECurrentASDAddress]
                ld      A,[IY+MWA_OPTIONS]
                
                ld      B,[OptNum]
                
                ;-- Option 5 ?
                cp      B,#1
                jr      NZ,StartL6
                  xor   A,#bOPTIONS_RANDOM
                  ld    [IY+MWA_OPTIONS],A
                  car   DISP_OPTION5
                  ret
StartL6:              
                ret

                
;--- Called if the crown is pulled --- 
mwaPushedCrownEvent:
                ld      IY, [CORECurrentASDAddress]

                ld      A, #CMD_JUMP
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE
                                
                ret           

;-------------------------------------------------------------------------------                
; OPTION 5 : RANDOM WATCH YES/NO
;-------------------------------------------------------------------------------                                               
DISP_CST_OPTION5:  
                LCD_CLR_DISPLAY
                
                ;-- Display the set number --
                ld      A, #05
                ld      IX, #LCDUPPERDMCOL1
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP
                
                ;-- Display Random --
                ld      IY, #MsgRandom
                ld      IX, #LCDMAINDMLINE1COL1
                ld      B, #06
                LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG
                
                ret
                
                
;-------------------------------------------------------------------------------                
DISP_OPTION5:  
                LCD_CLR_MAIN_DM_LINE2

                ;-- Display 'Watch:' --
                ld      IY, #MsgWatch
                ld      IX, #LCDMAINDMLINE2COL1
                ld      B, #06
                LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG

                ; Set IYReg the address of the MyWatch ASD.
                ld      IY, [CORECurrentASDAddress]
                ld      A,[IY+MWA_OPTIONS]
                bit     A,#bOPTIONS_RANDOM
                jr      NZ,DisplayYes                                

                  ld      IY, #MsgNo
                  ld      IX, #LCDMAINDMLINE2COL28
                  ld      B, #03
                  LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG
                  ret
                  
DisplayYes:    
                ld      IY, #MsgYes
                ld      IX, #LCDMAINDMLINE2COL28
                ld      B, #03
                LCD_DISP_UNFORMATTED_SMALL_PROP_WIDTH_DM_MSG                
                ret



                
                           
;-- DATAS ----------------------------------------------------------------------           
OptNum:         db 0

MsgRandom:      db DM5_R, DM5_A, DM5_N, DM5_D, DM5_O, DM5_M
MsgWatch:       db DM5_W, DM5_A, DM5_T, DM5_C, DM5_H, DM5_COLON
MsgYes:         db DM5_Y, DM5_E, DM5_S
MsgNo:          db DM5_SPACE, DM5_N, DM5_O
