;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File Name    : mwasnake.asm
; Purpose      : MyWatch Application Snake animation watch
; Version      : 2.10
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;DO NOT MODIFY THE FOLLOWING SUBROUTINE DEFINITION;;;;;;;;;;;;;;;;;

                IF @DEF('SUBROUTINE')
                    UNDEF SUBROUTINE
                ENDIF
                DEFINE  SUBROUTINE      "'mwasnake'"
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Module Name : mwaSnakeStateManager
; Description : MyWatch Application snake animation State Manager.
; Assumptions : Display is cleared on first time entry into the state.
; Input(s)    : CORECurrentEvent  - system event to be processed
;               COREEventArgument - event extra information
; Output(s)   : None
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

                GLOBAL  mwaSnakeStateManager

mwaSnakeStateManager:

                ; Set IYReg the address of the MyWatch ASD.
                ld      IY, [CORECurrentASDAddress]

                ld      A, [CORECurrentEvent]

                ; Check if state entry event.
                cp      A, #MWA_STATEENTRY
                jr      Z, mwaStateEntryEvent

                ; Check if mode depress event.
                cp      A, #MWA_MODEDEPRESS
                jr      Z, mwaModeDepressEvent

                ; Check if start/split depress event.
                cp      A, #MWA_STARTDEPRESS
                jr      Z, mwaStartDepressEvent

                ; Check if stop/reset depress event.
                cp      A, #MWA_STOPDEPRESS
                jr      Z, mwaStopDepressEvent
                
                ; Check if crown set event.
                cp      A, #MWA_CROWNSET
                jr      Z, mwaPulledCrownEvent

                ; Check if TOD display update event
                cp      A,#MWA_UPDATE_TODRES
                jr      Z,mwaUpdateTODResEvent
                
                ; Check if crown CW event.
                cp      A,#MWA_CWPULSES
                jr      Z,mwaCWEvent
                
                ; Check if crown CCW event.
                cp      A,#MWA_CCWPULSES
                jr      Z,mwaCCWEvent
                
                ret
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;; EVENT HANDLERS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


mwaModeDepressEvent:
                ;**************************************************************
                ;
                ;                       MODE DEPRESS
                ;
                ;**************************************************************

                ;This is default to go to the next mode

                CORE_REQ_MODE_CHANGE_NEXT

                ret


mwaStartDepressEvent:
                ;**************************************************************
                ;
                ;                       START DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTARTSTATE
                CORE_REQ_STATE_CHANGE
                ret


mwaStopDepressEvent:
                ;**************************************************************
                ;
                ;                       STOP DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTOPSTATE
                CORE_REQ_STATE_CHANGE
                ret
                

mwaPulledCrownEvent:
                ;**************************************************************
                ;
                ;                       CROWN SET
                ;
                ;**************************************************************

                ld      B, #CORESTATE2
                CORE_REQ_STATE_CHANGE

                ret

mwaCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CW
                ;
                ;**************************************************************

                ld      A, #CMD_NEXT
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE

                ret

mwaCCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CCW
                ;
                ;**************************************************************

                ld      A, #CMD_PREV
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE

                ret


mwaStateEntryEvent:
                ;**************************************************************
                ;
                ;                       STATE ENTRY
                ;
                ;**************************************************************

                car     DisplayLockFlag

                ; Enable pulse mode
                CORE_ENABLE_PULSE_MODE

                ;-- get a new seed for the random number generator --
                CORE_SET_RANDOM_SEED
                
                ;-- Display --
                car     ReadLocalTime
                car     Redraw_Full
                ;car     DisplayDateInSegment
                ;car     DisplayTime
                ;car     FirstDisplaySnake
                ;car     DisplayCustomDOW

                ;-- Enable seconds updates from the primary time zone resource
                ld      A, [COREPTZIndex]
                KTOD_ENABLE_DISP_UPD_SEC_EVENT
                
                ret


mwaUpdateTODResEvent:
                ;**************************************************************
                ;
                ;                       UPDATE TOD RESSOURCE (1s)
                ;
                ;**************************************************************

                ;Get the current update status flag of the primary time zone resource
                car     ReadLocalTime

                ld      A, [COREPTZIndex]
                KTOD_GET_UPDATE_FLAGS
                bit     A,#bKTODMinuteUpd
                jr      Z,lbUpdate1
                  ;LCD_CLR_DISPLAY
                  car     Redraw_Full
                  ;car     DisplayDateInSegment
                  ;car     DisplayCustomDOW
                  car     TestRandomMode
                  ret
lbUpdate1:                
                car     DisplayTime
                car     DisplaySnake
                
                Ret

 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; FUNCTIONS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

Redraw_Full:
                car     DisplayDateInSegment
                car     DisplayCustomDOW
                car     DisplayTime
                car     DisplaySnake
                ret

;-- Display the digital time    
DisplayTime:
                ;-- Display hour                
                ld  A, [dTODHour]
                ld  IX, #LCDMAINDMLINE1COL22
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_SUP_ZERO_MSD
                
                ;-- Display Colon
                ld  L, #DM5_COLON
                ld  IX, #LCDMAINDMLINE1COL32
                LCD_DISP_SMALL_PROP_WIDTH_DM_CHAR
                
                ;-- Display minute
                ld  A, [dTODMin]
                ld  IX, #LCDMAINDMLINE1COL34
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP
                
                ;-- Display second
                ld  A, [dTODSec]
                ld  IX, #LCDMAINDMLINE2COL34
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP
                
                Ret

;-- Display the original snake    
FirstDisplaySnake:
                ld  A,[SnakePos1x]
                ld  B,[SnakePos1y]
                ; Turn on Pixel (x = A, y = B)
                LCD_DISPLAY_MAIN_DM_PIXEL

                ld  A,[SnakePos2x]
                ld  B,[SnakePos2y]
                ; Turn on Pixel (x = A, y = B)
                LCD_DISPLAY_MAIN_DM_PIXEL

                ld  A,[SnakePos3x]
                ld  B,[SnakePos3y]
                ; Turn on Pixel (x = A, y = B)
                LCD_DISPLAY_MAIN_DM_PIXEL

                ld  A,[SnakePos4x]
                ld  B,[SnakePos4y]
                ; Turn on Pixel (x = A, y = B)
                LCD_DISPLAY_MAIN_DM_PIXEL

                ld  A,[SnakePos5x]
                ld  B,[SnakePos5y]
                ; Turn on Pixel (x = A, y = B)
                LCD_DISPLAY_MAIN_DM_PIXEL

                ld  A,[SnakePos6x]
                ld  B,[SnakePos6y]
                ; Turn on Pixel (x = A, y = B)
                LCD_DISPLAY_MAIN_DM_PIXEL

                ld  A,[SnakePos7x]
                ld  B,[SnakePos7y]
                ; Turn on Pixel (x = A, y = B)
                LCD_DISPLAY_MAIN_DM_PIXEL
                Ret
                
                
;-- Display the snake    
DisplaySnake:
                ;Turn off the last pixel
                ld  A,[SnakePos1x]
                ld  B,[SnakePos1y]
                ; Turn on Pixel (x = A, y = B)
                LCD_CLEAR_MAIN_DM_PIXEL
                
                ld  IX,#SnakePos1x
                ld  IY,#SnakePos2x
                ld  B, #12
                UTL_COPY_IYREG_TO_IXREG    

                ld  l,[SnakePos7x]
                ld  h,[SnakePos7y]
DS0:            
                ld  A,[Counter]
                cp  A,#00
                jr  NZ,DS_L1
                  ; Choose how many move in the same direction    
                  CORE_GENERATE_RANDOM_NUMBER
                  and   A,#15
                  ld    [Counter],A
                  
                  ; Choose the direction
                  CORE_GENERATE_RANDOM_NUMBER
                  and   A,#03
                  ld    [Direction],A

DS_L1:
                ;-- Current Direction=Forbidden Direction => Loop
                ld  a,[Direction]
                ld  b,[ForebiddenDirection]
                cp  A,B
                jr  Z,DSLOOP

                ;-- Direction is Rigth
                cp  A,#00 ;Rigth
                jr  NZ,DS1
                  cp  l,#20
                  jr  z,DSLOOP
                    ld  A,#01
                    inc l
                    jr  DS4
                
DS1:            ;-- Direction is Left
                cp  A,#01 ;Left
                jr  NZ,DS2                   
                  cp  l,#1
                  jr  z,DSLOOP
                    ld  A,#00
                    dec l
                    jr  DS4          
                          
DS2:            ;-- Direction is Up    
                cp  A,#02 ;Up
                jr  NZ,DS3   
                  cp  h,#1
                  jr  z,DSLOOP
                    ld  A,#03
                    dec h
                    jr  DS4        
                                            
DS3:            ;-- Direction is Down    
                cp  A,#03 ;Down
                jr  NZ,DS4   
                  cp  h,#11
                  jr  z,DSLOOP
                    ld  A,#02
                    inc h
                    jr  DS4                                                                

DS4:            ;-- End
                ld    [ForebiddenDirection],A
                    
                push  HL
                pop   BA
                
                ld  [SnakePos7x],A
                ld  [SnakePos7y],B
                
                car FirstDisplaySnake
                ; Turn on Pixel (x = A, y = B)
                ;LCD_DISPLAY_MAIN_DM_PIXEL
                
                ;-- Decremente the counter
                ld  HL,#Counter
                dec [HL]
                
                Ret
                
DSLOOP:            ;-- RESET Counter and loop to the start           
                ld  A,#0
                ld  [Counter],A
                jr  DS0
                
                
                
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; DATAS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

Direction:      db 0  ;0=Rigth 1=left 2=Up 3=Down
ForebiddenDirection:
                db 0  ;0=Rigth 1=left 2=Up 3=Down
Counter:        db 0

SnakePos1x:     db 6  ;The last pixel
SnakePos1y:     db 6
SnakePos2x:     db 7
SnakePos2y:     db 6
SnakePos3x:     db 8
SnakePos3y:     db 6
SnakePos4x:     db 9
SnakePos4y:     db 6
SnakePos5x:     db 10
SnakePos5y:     db 6
SnakePos6x:     db 11
SnakePos6y:     db 6
SnakePos7x:     db 12 ;The first pixel
SnakePos7y:     db 6











                
