;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File Name    : mwastart.asm
; Purpose      : MyWatch Application "Start" State Manager
;
;  Copyright Pierre Delore - Ray Allen - Ehood Baratz
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;DO NOT MODIFY THE FOLLOWING SUBROUTINE DEFINITION;;;;;;;;;;;;;;;;;

                IF @DEF('SUBROUTINE')
                    UNDEF SUBROUTINE
                ENDIF
                DEFINE  SUBROUTINE      "'mwaStart'"
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Module Name : mwaStartStateManager
; Description : MyWatch Application "Start" State Manager.
; Assumptions : Display is cleared on first time entry into the state.
; Input(s)    : CORECurrentEvent  - system event to be processed
;               COREEventArgument - event extra information
; Output(s)   : None
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

                GLOBAL  mwaStartStateManager

mwaStartStateManager:

                ; Set IYReg the address of the MyWatch ASD.
                ld      A, [CORECurrentEvent]

                ; Check if state entry event.
                cp      A, #MWA_STATEENTRY
                jr      Z, mwaStateEntryEvent

                ; Check if timeout hi-res done event.
                cp      A, #MWA_TIMEOUTDONEHIGHRES
                jr      Z, mwaTimeoutHiResDoneEvent
                
                ; Check if crown CW event.
                cp      A,#MWA_CWPULSES
                jr      Z,mwaCWEvent
                
                ; Check if crown CCW event.
                cp      A,#MWA_CCWPULSES
                jr      Z,mwaCCWEvent
                
                ; Check if mode depress event.
                cp      A, #MWA_MODEDEPRESS
                jr      Z, mwaModeDepressEvent

                ; Check if start/split depress event.
                cp      A, #MWA_STARTDEPRESS
                jr      Z, mwaStartDepressEvent

                ; Check if stop/reset depress event.
                cp      A, #MWA_STOPDEPRESS
                jr      Z, mwaStopDepressEvent
                
                ; Check if crown set event.
                cp      A, #MWA_CROWNSET
                jr      Z, mwaPulledCrownEvent

                ret
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;; EVENT HANDLERS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
mwaStateEntryEvent:
                ;**************************************************************
                ;
                ;                       STATE ENTRY
                ;
                ;**************************************************************

                ; Enable pulse mode
                CORE_ENABLE_PULSE_MODE

                ;-- Display The date in the segment --
                car     DisplayDateInSegment
                
                ;-- Stop the current melody --
                AUDSTOP_MELODY
                
                ; Display the week number
                ;ld      L, #DM5_W
                ld      L,[WNLetter]
                ld      IX, #LCDMAINDMLINE1COL1
                LCD_DISP_SMALL_FIXED_WIDTH_DM_CHAR

                ld      A, [dTODWeek]
                ld      IX, #LCDMAINDMLINE1COL7
                LCD_DISP_SMALL_FIXED_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP 
                
                ; Display the julian date
                ;ld      L, #DM5_D
                ld      L,[JDLetter]
                ld      IX, #LCDMAINDMLINE2COL1
                LCD_DISP_SMALL_FIXED_WIDTH_DM_CHAR


                ;First, calculate julian date
                
                LD      HL,#0
JulianLoop:
                INC     HL
                LD      IY,#dTODDate
                LD      A,#1
                KTOD_SUBTRACT_DAYS
                PUSH    B
                PUSH    HL
                LD      IY, #dTODDate
                KTOD_ADJUST_DATE_AND_YEAR
                POP     HL
                POP     B
                BIT     B,#32
                JR      Z, JulianLoop
                
                ;HL now contains the julian date !         
                UTL_CONVERT_2BYTE_HEX_TO_2BYTE_BCD
                
                ;BA now contains BCD julian date
                ld      IX, #LCDMAINDMLINE2COL7
                LCD_DISP_SMALL_FIXED_WIDTH_3DIG_DM_DATA_NO_ZERO_SUP
             
                
                ; Request 2sec timeout.
                CORE_REQ_TIMEOUT_HIRES  MWAHIRESTO_2SECONDS
                ret


mwaStartDepressEvent:
                ;**************************************************************
                ;
                ;                       START/SPLIT EVENT
                ;
                ;**************************************************************
                
                ld      A,#10
                ld      IY, [CORECurrentASDAddress]
                ld      B,[IY+MWA_OPTIONS]
                bit     B,#bOPTIONS_SOUND10
                jr      NZ,L1                    
                  ld      A,#15
L1:                  
                push    A
                
            		;Set the sound to the buffer we are filling
            		ld	    HL,#MRFSound
            		ld	    BA,#AUDCUSTOMMELODY
            		AUDSETUP_MELODYADDRESS
            
            		;IY will be the pointer into the sound buffer
            		ld	    IY,#MRFSound
            
            		;Construct the hours
            		;Convert hour to 12 hour format and convert it to hexadecimal
            		ld	    A,[dTODHour]
            		UTL_CONVERT_TO_12HR_FORMAT
            		UTL_CONVERT_1BYTE_BCD_TO_1BYTE_HEX
            		
            		ld	   [IY],A		;Number of hours
            		inc	   IY
            
            		ld	   B,[mrfLoTone]
            		ld	   [IY],B
            		inc	   IY		;The low tone
            
            		ld	   B,[mrfNoTone]
            		ld	   [IY],B
            		inc	   IY		;The no tone
            
            		;Load the minutes
            		ld	   A,[dTODMin]
            		UTL_CONVERT_1BYTE_BCD_TO_1BYTE_HEX
            		;A hold 0 to 59 in hex
            
            		ld	   H,#0
            		ld	   L,A
            		;ld	A,#10 ;15
            		pop    A
            		DIV		 ; L <- the quarters or 10 minutes, H<- the minutes
            
            		;Construct the quaters
            		;Z set by the DIV cmd	;Do we have Quarters ?
            		jr	   Z,mrfDoMinute	;No, Continue with minutes
            
            		;Sign the last group to continue
            		ld	   B,#AUDCONTINUEPATTERN
            		ld	   [IY],B
            		inc	   IY
            
            		;Add a silent
            		ld	   B,#1
            		ld	   [IY],B
            		inc	   IY
            
            		ld	   B,[mrfInterTone]
            		ld	   [IY],B
            		inc	   IY
            		
            		ld	   B,#AUDCONTINUEPATTERN
            		ld	   [IY],B
            		inc	   IY
            
            		;Construct the quarters
            		ld	   [IY],L
            		inc	   IY
            
            		ld	   B,[mrfHiTone] 
            		ld	   [IY],B
            		inc	   IY		;The high tone
            
            		ld	   B,[mrfLoTone]
            		ld	   [IY],B
            		inc	   IY		;The low tone
            
            		ld	   B,[mrfNoTone]
            		ld	   [IY],B
            		inc	   IY		;The no tone
            
mrfDoMinute:
            		cp	   H,#0		;Do we have minutes ?
            		jr	   Z,mrfFinishSound ;No, finish the sound
            
            		;Sign the last group to continue
            		ld	   B,#AUDCONTINUEPATTERN
            		ld	   [IY],B
            		inc	   IY
            
            		;Add a silent
            		ld	   B,#1
            		ld	   [IY],B
            		inc	   IY
            
            		ld	   B,[mrfInterTone]
            		ld	   [IY],B
            		inc	   IY
            		
            		ld	   B,#AUDCONTINUEPATTERN
            		ld	   [IY],B
            		inc	   IY
            
            		;Construct the minutes
            		ld	   [IY],H
            		inc	   IY		;Number fo minutes
            
            		ld	   B,[mrfHiTone]
            		ld	   [IY],B
            		inc	   IY		;The high tone
            
            		ld	   B,[mrfNoTone]
            		ld	   [IY],B
            		inc	   IY		;The no tone
            
            mrfFinishSound:
            		;Terminate the sound
            		ld	   B,#AUDENDMELODYPATTERN
            		ld	   [IY],B
            
            		;Sound the melody 
            		AUDSTART_SYSTEM_MELODY	AUDCUSTOMMELODY,AUDNOMELODYDONEEVENT


;------------------------------------------------------------------------------
;
; W A R N I N G !!! This is a fall through.  Do not rearrange.
;
;------------------------------------------------------------------------------                

mwaTimeoutHiResDoneEvent:
mwaCWEvent:
mwaCCWEvent:
mwaModeDepressEvent:
mwaStopDepressEvent:       
mwaPulledCrownEvent:      
                ;**************************************************************
                ;
                ;                       TIMEOUT HIRES DONE
                ;
                ;**************************************************************

                ld      IY, [CORECurrentASDAddress]
                ld      A, #CMD_JUMP
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE
                
                ret

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;--- Datas --

mrfNoTone:      db	(AUDNULL)|7
mrfLoTone:  		db	(AUD1KHZ)|7
mrfHiTone:  		db	(AUD3P2KHZ)|7
mrfInterTone:		db	(AUDNULL)|5


;-- Label for the configurator --
                db  'M','W','1','0','S'
                
JDLetter:       db DM5_D
WNLetter:       db DM5_W
