;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File Name    : mwastop.asm
; Purpose      : MyWatch Application "Stop" State Manager
;
;  Copyright Pierre Delore - Ray Allen
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;DO NOT MODIFY THE FOLLOWING SUBROUTINE DEFINITION;;;;;;;;;;;;;;;;;

                IF @DEF('SUBROUTINE')
                    UNDEF SUBROUTINE
                ENDIF
                DEFINE  SUBROUTINE      "'mwastop'"
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Module Name : mwaStopStateManager
; Description : MyWatch Application "Stop" State Manager.
; Assumptions : Display is cleared on first time entry into the state.
; Input(s)    : CORECurrentEvent  - system event to be processed
;               COREEventArgument - event extra information
; Output(s)   : None
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

                GLOBAL  mwaStopStateManager

mwaStopStateManager:

                ; Set IYReg the address of the MyWatch ASD.
                ld      IY, [CORECurrentASDAddress]

                ld      A, [CORECurrentEvent]

                ; Check if state entry event.
                cp      A, #MWA_STATEENTRY
                jr      Z, mwaStateEntryEvent
                
                ; Check if timeout hi-res done event.
                cp      A, #MWA_TIMEOUTDONEHIGHRES
                jr      Z, mwaTimeoutHiResDoneEvent

                ; Check if crown CW event.
                cp      A,#MWA_CWPULSES
                jr      Z,mwaCWEvent
                
                ; Check if crown CCW event.
                cp      A,#MWA_CCWPULSES
                jr      Z,mwaCCWEvent
                
                ; Check if mode depress event.
                cp      A, #MWA_MODEDEPRESS
                jr      Z, mwaModeDepressEvent

                ; Check if start/split depress event.
                cp      A, #MWA_STARTDEPRESS
                jr      Z, mwaStartDepressEvent

                ; Check if stop/reset depress event.
                cp      A, #MWA_STOPDEPRESS
                jr      Z, mwaStopDepressEvent

                ; Check if crown set event.
                cp      A, #MWA_CROWNSET
                jr      Z, mwaPulledCrownEvent                
                
                ret
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;; EVENT HANDLERS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
mwaStateEntryEvent:
                ;**************************************************************
                ;
                ;                       STATE ENTRY
                ;
                ;**************************************************************
        
                ; Enable pulse mode
                CORE_ENABLE_PULSE_MODE
        				
        				;-- Stop the current melody --
                AUDSTOP_MELODY

                ;show the background
        				LD    HL,#0F902H
        				LD    IY,#Line1
        				LD    B,#42
        				UTL_COPY_BUFFER	
        				LD    HL,#0FA02H
        				LD    IY,#Line2
        				LD    B,#42
        				UTL_COPY_BUFFER	
        				
                ld    IY, #lcdSegMsg
                LCD_DISP_SEG_LINE_MSG
        
        				;First, calculate julian date
        				;copy the primary time zone data
        				LD    A, #0
        				LD    IY, #MyWorkBuffer
        				KTOD_COPY_MDY_FROM_RESOURCE

				        LD    HL,#0  
JulianLoop:
				        INC   HL
        				LD    IY,#MyWorkBuffer
        				LD    A,#1
        				KTOD_SUBTRACT_DAYS
        				PUSH  B
        				PUSH  HL
        				LD    IY, #MyWorkBuffer
        				KTOD_ADJUST_DATE_AND_YEAR
        				POP   HL
        				POP   B
        				BIT   B,#32
        				JR    Z, JulianLoop

					      ;HL now contains the julian date !
        				LD   [Julian],HL
;        				UTL_CONVERT_2BYTE_HEX_TO_2BYTE_BCD
        				;BA now contains BCD julian date
;        				LCD_DISP_4DIG_SEG_DATA_WITH_ZERO_SUP

CalcCallipic:
                ;Get the date back
        				LD    A, #0
        				LD    IY, #MyWorkBuffer
        				KTOD_COPY_MDY_FROM_RESOURCE
        
        				LD    A,[MyWorkBuffer+3]
        				UTL_CONVERT_1BYTE_BCD_TO_1BYTE_HEX
        				LD    L,#100
        				MLT
        				PUSH  HL
        				LD    A,[MyWorkBuffer+2]
        				UTL_CONVERT_1BYTE_BCD_TO_1BYTE_HEX
        				LD    B,#0
        				POP   HL
        				ADD   BA,HL
        				;BA holds year in hex
        				LD    [Year],BA
        				LD    HL,BA
        				LD    A,#76
        				DIV
        				;h now holds the callipic year, L holds # of callipics
        				LD    [Callipic],H
        				LD    [Callipics],L
CalcLeaps:
        				LD    A,H
        				CP    A,#0
        				JR    Z,CalcDays
        				DEC   A
        				SRL   A	;divide by 4
        				SRL   A	;A now=#leaps
        				LD    [Leaps],A
CalcDays:
        				;days=callipic*365
        				LD    A,[Callipic]
        				LD    L,#109
        				MLT
        				LD    B,[Callipic]
        				LD    A,#0
        				ADD   BA,HL
        				;BA is now callipic*365
        				;add julian and leaps
        				LD    HL,[Julian]
        				ADD   BA,HL
        				LD    L,[Leaps]
        				LD    H,#0
        				ADD   BA,HL
        				LD    L,[Callipics]
        				LD    H,#0
        				SUB   BA,HL
        				;BA is now #days
CalcPhase:	
        				;Phase=Days*47+Offset
        				LD    HL,BA
        				LD    A,#47
        				CAR   FMUL_Multiply16by8	
        				;result in A:HL
        				;add offset
        				LD    IX,#1222
        				ADD   HL,IX
        				ADC   A,#0
        				;A:HL is now phase * 1388
        				;Now, need to divide by 1388
CalcPhaseDivideLoop:
        				;subract from HL until goes negative
        				LD    [Phase],HL
        				SUB   HL,#1388
        				JR    NC,CalcPhaseDivideLoop
        				;HL now negative
        				CP    A,#0
        				JR    Z,CalcPosition		;all done!
CalcPhaseDivideCarry:
        				DEC   A
        				JR    CalcPhaseDivideLoop

CalcPosition:
        				;Multiply phase by 32 and divide by 1388 (or, muliply by 8 and divide by 347)
        				LD    HL,[Phase]
        				LD    A,#32
        				CAR   FMUL_Multiply16by8	
        				;Now divide HL by 1388
        				LD    A,#0		;make sure it's zero
        
CalcPositionDivideLoop:
        				;subract from HL until goes negative
        				INC   A
        				SUB   HL,#1388
        				JR    NC,CalcPositionDivideLoop
        				DEC   A
        				LD [Position],A
        
ShowPosition:
        				LD    A,[Position]
        				LD    B,#8
        				ADD   A,#4
        				CAR SetPixelSaveA
        				LD    B,#9
        				CAR SetPixelSaveA
        				LD    B,#10
        				CAR SetPixelSaveA
        				DEC   A
        				LD    B,#9
        				CAR SetPixelSaveA
        				LD    B,#10
        				CAR SetPixelSaveA
        				DEC   A
        				LD    B,#10
        				CAR SetPixelSaveA
        				ADD   A,#3
        				LD    B,#9
        				CAR SetPixelSaveA
        				LD    B,#10
        				CAR SetPixelSaveA
        				INC   A
        				LD    B,#10
        				CAR SetPixelSaveA

                ; Request 2sec timeout.
                CORE_REQ_TIMEOUT_HIRES  MWAHIRESTO_2SECONDS
        
        				RET

;-- Save A and display the pixel then restore A --
SetPixelSaveA:
        				PUSH  A
        				LCD_DISPLAY_MAIN_DM_PIXEL
        				POP   A
        				RET
        

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Module Name : FMUL_Multiply16by8
; Description : Multiplies integers A*HL=A:HL (24 bit result)  destroys B,A,HL
; Input(s)    : A,HL
; Output(s)   : A:HL
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
				;GLOBAL FMUL_Multiply16by8
FMUL_Multiply16by8:				;A*HL=A:HL (24 bit result)  destroys B,A,HL
        				LD    B,H		;multiplication		
        				MLT
        				PUSH  L		;result #1
        				PUSH  H		;semi result#2
        				LD    L,B
        				MLT
        				POP   A		;semi result#2
        				LD    B,L
        				ADD   A,B
        				PUSH  A		;result#2
        				LD    A,H
        				ADC   A,#0	
        				POP   H
        				POP   L
        				RET



mwaTimeoutHiResDoneEvent:
mwaCWEvent:
mwaCCWEvent:
mwaModeDepressEvent:
mwaStartDepressEvent:
mwaStopDepressEvent:    
mwaPulledCrownEvent:         
                ;**************************************************************
                ;
                ;                       TIMEOUT HIRES DONE
                ;
                ;**************************************************************

;                ld      B,[IY + MWA_ACTIVE_STATE]
;                CORE_REQ_STATE_CHANGE
                
                ld      IY, [CORECurrentASDAddress]
                ld      A, #CMD_JUMP
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE
                
                
                ret


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;--- Datas --

Position:       db 00
Phase:          dw 00
Days:           dw 00	;#elapsed days in current Callipic cycle
Julian:         dw 00
Year:           dw 00
Callipic:       db 00  ;position in the 76 year callipic cycle
Callipics:      db 00	;elapsed cycles since year 1
Leaps:          db 00	;#past leap years in current callipic cycle

MyWorkBuffer:
                db 00 ;date
                db 00 ;month
                db 00 ;year lo
                db 00 ;year hi

lcdSegMsg:      db SEG_SPACE, SEG_M, SEG_O, SEG_O, SEG_N, SEG_SPACE


;Line1:          db 0Ch,12h,01h,01h,01h,12h,0ch,00h,0ch,12h,01h,1fh,1fh,1eh,0ch
;	              db 00h,0ch,1eh,1fh,1fh,1fh,1eh,0ch,00h,0ch,1eh,1fh,1fh,01h,12h
;	              db 0ch,00h,0ch,12h,01h,01h,01h,12h,0ch,00h,00h,00h

;Line2:          db 00h,00h,01h,21h,01h,00h,00h,00h,00h,00h,01h,21h,01h,00h,00h
;                db 00h,00h,00h,01h,21h,01h,00h,00h,00h,00h,00h,01h,21h,01h,00h 
;                db 00h,00h,00h,00h,01h,21h,01h,00h,00h,00h,00h,00h

Line1:
                ;New
                db 0ch,01eh,01fh,01fh,01fh,01eh,0ch,0h
                ;wax 1/2
                db 0ch,01eh,01fh,01fh,01h,012h,0ch,0h
                ;Full
                db 0Ch,012h,01h,01h,01h,012h,0ch,0h
                ;wane 1/2
                db 0ch,012h,01h,01fh,01fh,01eh,0ch,00h
                ;New
                db 0ch,01eh,01fh,01fh,01fh,01eh,0ch,0h,0h,0h

Line2:
                ;New
                db 0h,0h,1h,21h,01h,0h,0h,0h
                ;wax 1/2      
                db 0h,0h,01h,021h,01h,0h,0h,0h
                ;Full
                db 0h,0h,1h,021h,01h,0h,0h,0h
                ;wane 1/2
                db 0h,0h,01h,021h,01h,0h,0h,0h
                ;New
                db 0h,0h,1h,21h,01h,0h,0h,0h,0h,0h 
