;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File Name    : mwavbin.asm
; Purpose      : MyWatch Application vertical binary State Manager
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;DO NOT MODIFY THE FOLLOWING SUBROUTINE DEFINITION;;;;;;;;;;;;;;;;;

                IF @DEF('SUBROUTINE')
                    UNDEF SUBROUTINE
                ENDIF
                DEFINE  SUBROUTINE      "'mwavbin'"
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Module Name : mwaVBinaryStateManager
; Description : MyWatch Application vertical binary State Manager.
; Assumptions : Display is cleared on first time entry into the state.
; Input(s)    : CORECurrentEvent  - system event to be processed
;               COREEventArgument - event extra information
; Output(s)   : None
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

                GLOBAL  mwaVBinaryStateManager

mwaVBinaryStateManager:

                ; Set IYReg the address of the MyWatch ASD.
                ld      IY, [CORECurrentASDAddress]

                ld      A, [CORECurrentEvent]

                ; Check if state entry event.
                cp      A, #MWA_STATEENTRY
                jr      Z, mwaStateEntryEvent

                ; Check if mode depress event.
                cp      A, #MWA_MODEDEPRESS
                jr      Z, mwaModeDepressEvent

                ; Check if start/split depress event.
                cp      A, #MWA_STARTDEPRESS
                jr      Z, mwaStartDepressEvent

                ; Check if stop/reset depress event.
                cp      A, #MWA_STOPDEPRESS
                jr      Z, mwaStopDepressEvent
                
                ; Check if crown set event.
                cp      A, #MWA_CROWNSET
                jr      Z, mwaPulledCrownEvent

                ; Check if TOD display update event
                cp      A,#MWA_UPDATE_TODRES
                jr      Z,mwaUpdateTODResEvent
                
                ; Check if crown CW event.
                cp      A,#MWA_CWPULSES
                jr      Z,mwaCWEvent
                
                ; Check if crown CCW event.
                cp      A,#MWA_CCWPULSES
                jr      Z,mwaCCWEvent
                
                ret
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;; EVENT HANDLERS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


mwaModeDepressEvent:
                ;**************************************************************
                ;
                ;                       MODE DEPRESS
                ;
                ;**************************************************************

                ;This is default to go to the next mode

                CORE_REQ_MODE_CHANGE_NEXT

                ret


mwaStartDepressEvent:
                ;**************************************************************
                ;
                ;                       START DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTARTSTATE
                CORE_REQ_STATE_CHANGE
                ret


mwaStopDepressEvent:
                ;**************************************************************
                ;
                ;                       STOP DEPRESS
                ;
                ;**************************************************************

                ld      B, #MWASTOPSTATE
                CORE_REQ_STATE_CHANGE
                ret
                

mwaPulledCrownEvent:
                ;**************************************************************
                ;
                ;                       CROWN SET
                ;
                ;**************************************************************

                ld      B, #CORESTATE2
                CORE_REQ_STATE_CHANGE

                ret

mwaCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CW
                ;
                ;**************************************************************

                ld      A, #CMD_NEXT
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE

                ret

mwaCCWEvent:
                ;**************************************************************
                ;
                ;                       CROWN CCW
                ;
                ;**************************************************************

                ld      A, #CMD_PREV
                ld      [MWA_Command],A
                ld      B, #CORESTATE1
                CORE_REQ_STATE_CHANGE

                ret


mwaStateEntryEvent:
                ;**************************************************************
                ;
                ;                       STATE ENTRY
                ;
                ;**************************************************************

                car     DisplayLockFlag

                ; Enable pulse mode
                CORE_ENABLE_PULSE_MODE

                car     ReadLocalTime
                car     Redraw_Full
                ;car     DisplayEmptyHMBinWatch
                ;car     DisplayEmptySBinWatch
                ;car     DisplayDateInSegment
                ;car     DisplayTime
                ;car     DisplaySBinWatch
                ;car     DisplayHMBinWatch
                ;car     DisplayCustomDOW

                ;-- Enable seconds updates from the primary time zone resource
                ld      A, [COREPTZIndex]
                KTOD_ENABLE_DISP_UPD_SEC_EVENT
                
                ret


mwaUpdateTODResEvent:
                ;**************************************************************
                ;
                ;                       UPDATE TOD RESSOURCE (1s)
                ;
                ;**************************************************************

                ;Get the current update status flag of the primary time zone resource
                car     ReadLocalTime

                ld      A, [COREPTZIndex]
                KTOD_GET_UPDATE_FLAGS
                bit     A,#bKTODMinuteUpd
                jr      Z,lbUpdate1
                  ;LCD_CLR_DISPLAY
                  car     Redraw_Full
                  ;car     DisplayEmptyHMBinWatch
                  ;car     DisplayDateInSegment
                  ;car     DisplayHMBinWatch
                  ;car     DisplayCustomDOW
                  car     TestRandomMode
                  ret
lbUpdate1:                
                car     DisplayEmptySBinWatch
                car     DisplaySBinWatch
                car     DisplayTime
                
                Ret

 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; FUNCTIONS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

Redraw_Full:
                car     DisplayEmptyHMBinWatch
                car     DisplayDateInSegment
                car     DisplayHMBinWatch
                car     DisplayCustomDOW
                car     DisplayEmptySBinWatch
                car     DisplaySBinWatch
                car     DisplayTime
                ret

;-- Display empty HM binary Watch
DisplayEmptyHMBinWatch:
                ld      B, #14
                ld      IY,#Line1HM
                ld      IX, #0F902H
                UTL_COPY_IYREG_TO_IXREG

                ld      B, #14
                ld      IY,#Line2HM
                ld      IX, #0FA02H
                UTL_COPY_IYREG_TO_IXREG
                RET

                
;-- Display empty S binary Watch
DisplayEmptySBinWatch:
                ld      B, #3
                ld      IY,#Line1S
                ld      IX, #0F912H
                UTL_COPY_IYREG_TO_IXREG
                
                ld      B, #3
                ld      IY,#Line2S
                ld      IX, #0FA12H
                UTL_COPY_IYREG_TO_IXREG
                RET

 
;-- Display S binary Watch
DisplaySBinWatch:
                ; S:16
                ; 11,9,7,5,3,1

                ld    A,[dTODSec]
                UTL_CONVERT_1BYTE_BCD_TO_1BYTE_HEX
                
                ld    IY,#YPixel
                ld    B,#6
SBinL1:
                push  B
                SRL   A
                push  A
                JR    NC,SBinL2
                  ; Turn on Pixel (x = A, y = B)
                  ld    A,#17
                  ld    B,[IY]
                  LCD_DISPLAY_MAIN_DM_PIXEL
                  ld    A,#19
                  ld    B,[IY]
                  LCD_DISPLAY_MAIN_DM_PIXEL
                  
SBinL2:
                pop   A
                
                inc   IY
                pop   B
                djr   NZ,SBinL1
                
                RET         


;-- Display HM binary Watch
DisplayHMBinWatch:
                ; M:9
                ; H:2
                ; 11,9,7,5,3,1
                
                ;-- Display binary minute --
                ld    A,[dTODMin]
                UTL_CONVERT_1BYTE_BCD_TO_1BYTE_HEX
                
                ld    IY,#YPixel
                ld    B,#6
MBinL1:
                push  B
                SRL   A
                push  A
                JR    NC,MBinL2
                  ; Turn on Pixel (x = A, y = B)
                  ld    A,#9
                  ld    B,[IY]
                  LCD_DISPLAY_MAIN_DM_PIXEL
                  ld    A,#11
                  ld    B,[IY]
                  LCD_DISPLAY_MAIN_DM_PIXEL
MBinL2:
                pop   A
                
                inc   IY
                pop   B
                djr   NZ,MBinL1


                ;-- Display binary hour --
                ld    A,[dTODHour]
                UTL_CONVERT_1BYTE_BCD_TO_1BYTE_HEX
                
                ld    IY,#YPixel
                ld    B,#5
HBinL1:
                push  B
                SRL   A
                push  A
                JR    NC,HBinL2
                  ; Turn on Pixel (x = A, y = B)
                  ld    A,#1
                  ld    B,[IY]
                  LCD_DISPLAY_MAIN_DM_PIXEL
                  ld    A,#3
                  ld    B,[IY]
                  LCD_DISPLAY_MAIN_DM_PIXEL
HBinL2:
                pop   A
                
                inc   IY
                pop   B
                djr   NZ,HBinL1

                RET



                
;-- Display the digital time    
DisplayTime:
                ;-- Display hour                
                ld  A, [dTODHour]
                ld  IX, #LCDMAINDMLINE1COL22
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_SUP_ZERO_MSD
                
                ;-- Display Colon
                ld  L, #DM5_COLON
                ld  IX, #LCDMAINDMLINE1COL32
                LCD_DISP_SMALL_PROP_WIDTH_DM_CHAR
                
                ;-- Display minute
                ld  A, [dTODMin]
                ld  IX, #LCDMAINDMLINE1COL34
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP
                
                ;-- Display second
                ld  A, [dTODSec]
                ld  IX, #LCDMAINDMLINE2COL34
                LCD_DISP_SMALL_PROP_WIDTH_2DIG_DM_DATA_NO_ZERO_SUP
                
                Ret

                
                
;;;;;;;;;;;;;;;;;;;;;;;;;;;;; DATAS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


Line1HM:        db 00H,14H,00H,00H,00H,00H,00H,00H,00H,15H,00H,00H,00H,00H
Line2HM:        db 00H,2AH,00H,00H,00H,05H,00H,00H,00H,2AH,00H,00H,00H,04H
Line1S:         db 00H,15H,00H
Line2S:         db 00H,2AH,00H

YPixel:         db 11,09,07,05,03,01


; S:16
; 11,9,7,5,3,1
; M:9
; H:2






                
